# -*- coding: utf-8 -*-

#--------------------------------------
# django 0.96     |     django 0.97
#--------------------------------------
# FloatField      |     DecimalField

from django.db import models
from codebook import *

class DsdDomain(models.Model):
    dsddom = models.IntegerField(primary_key=True, verbose_name='ID Domény')
    domjme = models.CharField(max_length=254, verbose_name='Doménové jméno')
    domadm = models.DateTimeField(verbose_name='Datum adm. testu')
    domtch = models.DateTimeField(verbose_name='Datum tech. testu')
    domdod = models.DateField(verbose_name='Začátek reg. procesu')
    domddo = models.DateTimeField(verbose_name='Konec registrace')
    domkst = models.TextField(verbose_name='Stav domény', choices=domainState) # This field type is a guess.
    domgen = models.TextField(verbose_name='Doména v zóně', choices=domainInZone) # This field type is a guess.
    domdes = models.CharField(max_length=254, verbose_name='Popis domény')
    domtno = models.TextField(verbose_name='Typ notifikace', choices=notifyType) # This field type is a guess.
    dommno = models.CharField(max_length=128, verbose_name='Notifikační email')
    domtat = models.SmallIntegerField(verbose_name='Typ autorizace')
    _stpins = models.DateTimeField()
    _usrins = models.CharField(max_length=8) # This field type is a guess.
    _stpupd = models.DateTimeField()
    _usrupd = models.CharField(max_length=8) # This field type is a guess.
    _numver = models.IntegerField()
    _nxtrec = models.IntegerField()
    _grpusr = models.CharField(max_length=32) # This field type is a guess.
    _lvlsec = models.IntegerField()

    def __str__(self):
        return "%s <%d>" % (self.domjme, self.dsddom)

    def subjects(self):
        return DsdDomain_x_Subject.objects.filter(dsddom = self)

    def dns(self):
        return DsdDns.objects.filter(dsddom = self)

    def rules(self):
        return DsdSou.objects.filter(dsddom = self)

    def history(self):
        return History.objects.filter(hiskey = self.dsddom)

    class Meta:
        db_table = 'dsd_dom'
        verbose_name = 'doména'
        verbose_name_plural = 'domény'
        get_latest_by = 'domdod'

    class Admin:
        fields = (
            (None, {
                'fields': ('domjme', 'domdes', 'domkst', 'domgen', 'domdod', 'domddo')
            }),
            ('Technické a administrativní testy', {
                'classes': 'collapse',
                'fields' : ('domadm', 'domtch')
            }),
        )
        date_hierarchy = 'domdod'
        ordering = ('domjme', 'domdod')
        list_display = ('domjme', 'domdes', 'domkst', 'domdod', 'domddo')
        list_filter = ('domddo',)
        search_fields = ['=domjme']

class LrrDsdDomain(models.Model):
    dsddom = models.IntegerField(primary_key=True, verbose_name='ID Domény')
    domjme = models.CharField(max_length=254, verbose_name='Doménové jméno')
    domadm = models.DateTimeField(verbose_name='Datum adm. testu')
    domtch = models.DateTimeField(verbose_name='Datum tech. testu')
    domdod = models.DateField(verbose_name='Začátek reg. procesu')
    domddo = models.DateTimeField(verbose_name='Konec registrace')
    domkst = models.TextField(verbose_name='Stav domény', choices=domainState) # This field type is a guess.
    domgen = models.TextField(verbose_name='Doména v zóně', choices=domainInZone) # This field type is a guess.
    domdes = models.CharField(max_length=254, verbose_name='Popis domény')
    domtno = models.TextField(verbose_name='Typ notifikace', choices=notifyType) # This field type is a guess.
    dommno = models.CharField(max_length=128, verbose_name='Notifikační email')
    domtat = models.SmallIntegerField(verbose_name='Typ autorizace')
    _stpins = models.DateTimeField()
    _usrins = models.CharField(max_length=8) # This field type is a guess.
    _stpupd = models.DateTimeField()
    _usrupd = models.CharField(max_length=8) # This field type is a guess.
    _numver = models.IntegerField()
    _nxtrec = models.IntegerField()
    _grpusr = models.CharField(max_length=32) # This field type is a guess.
    _lvlsec = models.IntegerField()

    def __str__(self):
        return "%s <%d>" % (self.domjme, self.dsddom)

    def subjects(self):
        return LrrDsdDomain_x_Subject.objects.filter(dsddom = self)

    def dns(self):
        return LrrDsdDns.objects.filter(dsddom = self)

    def rules(self):
        return LrrDsdSou.objects.filter(dsddom = self)

    def history(self):
        return History.objects.filter(hiskey = self.dsddom)

    class Meta:
        db_table = 'lrr_dsd_dom'
        verbose_name = 'doména'
        verbose_name_plural = 'domény'
        get_latest_by = 'domdod'

class DsdContact(models.Model):
    dsdkon = models.IntegerField(primary_key=True)
    konjme = models.CharField(max_length=64)
    konpri = models.CharField(max_length=128)
    konuli = models.CharField(max_length=254)
    konmis = models.CharField(max_length=254)
    konpsc = models.TextField() # This field type is a guess.
    konsta = models.TextField() # This field type is a guess.
    kontel = models.CharField(max_length=64)
    konfax = models.CharField(max_length=64)
    konemk = models.CharField(max_length=128)
    konemr = models.CharField(max_length=128)
    koneno = models.CharField(max_length=128)
    konrid = models.CharField(unique=True, max_length=254)
    konnps = models.CharField(max_length=32)
    kontps = models.TextField(choices=idType) # This field type is a guess.
    kondnr = models.DateField()
    konpsw = models.TextField() # This field type is a guess.
    kontno = models.TextField(choices=notifyType) # This field type is a guess.
    kondod = models.DateField()
    konddo = models.DateTimeField()
    _stpins = models.DateTimeField()
    _usrins = models.TextField() # This field type is a guess.
    _stpupd = models.DateTimeField()
    _usrupd = models.TextField() # This field type is a guess.
    _numver = models.IntegerField()
    _nxtrec = models.IntegerField()
    _grpusr = models.TextField() # This field type is a guess.
    _lvlsec = models.IntegerField()

    def __str__(self):
        person = "%s %s" % (getattr(self, 'konpri', ''), getattr(self, 'konjme', ''))
        return "%s <%d> (%s)" % (self.konrid, self.dsdkon, person.strip())

    def history(self):
        return History.objects.filter(hiskey = self.dsdkon)

    class Meta:
        db_table = 'dsd_kon'
        ordering = ('konpri', 'konjme', 'konrid')
        verbose_name = 'kontakt'
        verbose_name_plural = 'kontakty'

    class Admin:
        pass

class LrrDsdContact(models.Model):
    dsdkon = models.IntegerField(primary_key=True)
    konjme = models.CharField(max_length=64)
    konpri = models.CharField(max_length=128)
    konuli = models.CharField(max_length=254)
    konmis = models.CharField(max_length=254)
    konpsc = models.TextField() # This field type is a guess.
    konsta = models.TextField() # This field type is a guess.
    kontel = models.CharField(max_length=64)
    konfax = models.CharField(max_length=64)
    konemk = models.CharField(max_length=128)
    konemr = models.CharField(max_length=128)
    koneno = models.CharField(max_length=128)
    konrid = models.CharField(unique=True, max_length=254)
    konnps = models.CharField(max_length=32)
    kontps = models.TextField(choices=idType) # This field type is a guess.
    kondnr = models.DateField()
    konpsw = models.TextField() # This field type is a guess.
    kontno = models.TextField(choices=notifyType) # This field type is a guess.
    kondod = models.DateField()
    konddo = models.DateTimeField()
    _stpins = models.DateTimeField()
    _usrins = models.TextField() # This field type is a guess.
    _stpupd = models.DateTimeField()
    _usrupd = models.TextField() # This field type is a guess.
    _numver = models.IntegerField()
    _nxtrec = models.IntegerField()
    _grpusr = models.TextField() # This field type is a guess.
    _lvlsec = models.IntegerField()

    def __str__(self):
        person = "%s %s" % (getattr(self, 'konpri', ''), getattr(self, 'konjme', ''))
        return "%s <%d> (%s)" % (self.konrid, self.dsdkon, person.strip())

    def history(self):
        return History.objects.filter(hiskey = self.dsdkon)

    class Meta:
        db_table = 'lrr_dsd_kon'
        ordering = ('konpri', 'konjme', 'konrid')
        verbose_name = 'kontakt'
        verbose_name_plural = 'kontakty'

class DsdSubject(models.Model):
    dsdpfo = models.IntegerField(primary_key=True)
    pfotyp = models.TextField(choices=subjectType) # This field type is a guess.
    pfosts = models.TextField() # This field type is a guess.
    pfonaz = models.CharField(max_length=254)
    pfodnr = models.DateField()
    pfojme = models.CharField(max_length=64)
    pfopri = models.CharField(max_length=128)
    pfoico = models.TextField() # This field type is a guess.
    pfodic = models.TextField() # This field type is a guess.
    pfocuc = models.TextField() # This field type is a guess.
    pfoema = models.CharField(max_length=128)
    pforid = models.CharField(unique=True, max_length=254)
    pfotno = models.TextField(choices=notifyType) # This field type is a guess.
    pfomno = models.CharField(max_length=128)
    pfotat = models.SmallIntegerField()
    pfodod = models.DateField()
    pfoddo = models.DateTimeField()
    _stpins = models.DateTimeField()
    _usrins = models.TextField() # This field type is a guess.
    _stpupd = models.DateTimeField()
    _usrupd = models.TextField() # This field type is a guess.
    _numver = models.IntegerField()
    _nxtrec = models.IntegerField()
    _grpusr = models.TextField() # This field type is a guess.
    _lvlsec = models.IntegerField()

    def __str__(self):
        company = self.pfonaz.strip()
        person = "%s %s" % (getattr(self, 'pfojme', ''), getattr(self, 'pfopri', ''))
        person = person.strip()
        return "%s: %s <%s> (%s)" % (self.pfotyp, self.pforid, self.dsdpfo, company or person)

#    def addresses(self):
#        return self.dsdaddress_set.all()

    def contacts(self):
        return DsdContact_x_Subject.objects.filter(dsdpfo = self)

    def history(self):
        return History.objects.filter(hiskey = self.dsdpfo)

    class Meta:
        db_table = 'dsd_pfo'
        verbose_name = 'subjekt'
        verbose_name_plural = 'subjekty'

    class Admin:
        pass

class LrrDsdSubject(models.Model):
    dsdpfo = models.IntegerField(primary_key=True)
    pfotyp = models.TextField(choices=subjectType) # This field type is a guess.
    pfosts = models.TextField() # This field type is a guess.
    pfonaz = models.CharField(max_length=254)
    pfodnr = models.DateField()
    pfojme = models.CharField(max_length=64)
    pfopri = models.CharField(max_length=128)
    pfoico = models.TextField() # This field type is a guess.
    pfodic = models.TextField() # This field type is a guess.
    pfocuc = models.TextField() # This field type is a guess.
    pfoema = models.CharField(max_length=128)
    pforid = models.CharField(unique=True, max_length=254)
    pfotno = models.TextField(choices=notifyType) # This field type is a guess.
    pfomno = models.CharField(max_length=128)
    pfotat = models.SmallIntegerField()
    pfodod = models.DateField()
    pfoddo = models.DateTimeField()
    _stpins = models.DateTimeField()
    _usrins = models.TextField() # This field type is a guess.
    _stpupd = models.DateTimeField()
    _usrupd = models.TextField() # This field type is a guess.
    _numver = models.IntegerField()
    _nxtrec = models.IntegerField()
    _grpusr = models.TextField() # This field type is a guess.
    _lvlsec = models.IntegerField()

    def __str__(self):
        company = self.pfonaz.strip()
        person = "%s %s" % (getattr(self, 'pfojme', ''), getattr(self, 'pfopri', ''))
        person = person.strip()
        return "%s: %s <%s> (%s)" % (self.pfotyp, self.pforid, self.dsdpfo, company or person)

#    def addresses(self):
#        return self.dsdaddress_set.all()

    def contacts(self):
        return LrrDsdContact_x_Subject.objects.filter(dsdpfo = self)

    def history(self):
        return History.objects.filter(hiskey = self.dsdpfo)

    class Meta:
        db_table = 'lrr_dsd_pfo'
        verbose_name = 'subjekt'
        verbose_name_plural = 'subjekty'

class DsdAddress(models.Model):
    dsdadr = models.IntegerField(primary_key=True)
    dsdpfo = models.ForeignKey(DsdSubject, db_column='dsdpfo')
    adrtyp = models.TextField() # This field type is a guess.
    adruli = models.CharField(max_length=254)
    adrmis = models.CharField(max_length=254)
    adrpsc = models.TextField() # This field type is a guess.
    adrsta = models.TextField() # This field type is a guess.
    adrdod = models.DateField()
    adrddo = models.DateField()
    _stpins = models.DateTimeField()
    _usrins = models.TextField() # This field type is a guess.
    _stpupd = models.DateTimeField()
    _usrupd = models.TextField() # This field type is a guess.
    _numver = models.IntegerField()
    _nxtrec = models.IntegerField()
    _grpusr = models.TextField() # This field type is a guess.
    _lvlsec = models.IntegerField()

    def __str__(self):
        return "%d:%s, %s..." % (self.dsdadr, self.adrmis, str(self.adruli)[:20])

    class Meta:
        db_table = 'dsd_adr'
        verbose_name = 'adresa'
        verbose_name_plural = 'adresy'

    class Admin:
        fields = (
            (None, {
                'fields': ('adruli', 'adrmis', 'adrpsc', 'adrsta')
            }),
            ('Platnost', {
                'classes': 'collapse',
                'fields' : ('adrdod', 'adrddo')
            }),
        )
        list_display = ('dsdpfo', 'adrtyp', 'adruli', 'adrmis', 'adrpsc', 'adrsta')

class LrrDsdAddress(models.Model):
    dsdadr = models.IntegerField(primary_key=True)
    dsdpfo = models.ForeignKey(LrrDsdSubject, db_column='dsdpfo')
    adrtyp = models.TextField() # This field type is a guess.
    adruli = models.CharField(max_length=254)
    adrmis = models.CharField(max_length=254)
    adrpsc = models.TextField() # This field type is a guess.
    adrsta = models.TextField() # This field type is a guess.
    adrdod = models.DateField()
    adrddo = models.DateField()
    _stpins = models.DateTimeField()
    _usrins = models.TextField() # This field type is a guess.
    _stpupd = models.DateTimeField()
    _usrupd = models.TextField() # This field type is a guess.
    _numver = models.IntegerField()
    _nxtrec = models.IntegerField()
    _grpusr = models.TextField() # This field type is a guess.
    _lvlsec = models.IntegerField()

    def __str__(self):
        return "%d:%s, %s..." % (self.dsdadr, self.adrmis, str(self.adruli)[:20])

    class Meta:
        db_table = 'lrr_dsd_adr'
        verbose_name = 'adresa'
        verbose_name_plural = 'adresy'

class DsdContact_x_Subject(models.Model):
    dsdkxs = models.IntegerField(primary_key=True)
    dsdpfo = models.ForeignKey(DsdSubject, db_column='dsdpfo')
    dsdkon = models.ForeignKey(DsdContact, db_column='dsdkon')
    kxstyp = models.TextField() # This field type is a guess.
    kxspod = models.DateTimeField()
    kxspdo = models.DateTimeField()
    _stpins = models.DateTimeField()
    _usrins = models.TextField() # This field type is a guess.
    _stpupd = models.DateTimeField()
    _usrupd = models.TextField() # This field type is a guess.
    _numver = models.IntegerField()
    _nxtrec = models.IntegerField()
    _grpusr = models.TextField() # This field type is a guess.
    _lvlsec = models.IntegerField()

    def __str__(self):
        return "[%s] x [%s] <%s - %s>" % (self.dsdkon, self.dsdpfo, self.kxspod, self.kxspdo)

    class Meta:
        db_table = 'dsd_kxs'
        verbose_name = 'kon_x_subj'
        verbose_name_plural = 'kon_x_subjs'

    class Admin:
        pass

class LrrDsdContact_x_Subject(models.Model):
    dsdkxs = models.IntegerField(primary_key=True)
    dsdpfo = models.ForeignKey(LrrDsdSubject, db_column='dsdpfo')
    dsdkon = models.ForeignKey(LrrDsdContact, db_column='dsdkon')
    kxstyp = models.TextField() # This field type is a guess.
    kxspod = models.DateTimeField()
    kxspdo = models.DateTimeField()
    _stpins = models.DateTimeField()
    _usrins = models.TextField() # This field type is a guess.
    _stpupd = models.DateTimeField()
    _usrupd = models.TextField() # This field type is a guess.
    _numver = models.IntegerField()
    _nxtrec = models.IntegerField()
    _grpusr = models.TextField() # This field type is a guess.
    _lvlsec = models.IntegerField()

    def __str__(self):
        return "[%s] x [%s] <%s - %s>" % (self.dsdkon, self.dsdpfo, self.kxspod, self.kxspdo)

    class Meta:
        db_table = 'lrr_dsd_kxs'
        verbose_name = 'kon_x_subj'
        verbose_name_plural = 'kon_x_subjs'

class DsdDomain_x_Subject(models.Model):
    dsddxs = models.IntegerField(primary_key=True)
    dsddom = models.ForeignKey(DsdDomain, db_column='dsddom')
    dsdpfo = models.ForeignKey(DsdSubject, db_column='dsdpfo')
    dxsdod = models.DateField()
    dxsddo = models.DateTimeField()
    dxstyp = models.TextField(choices=domainSubjectType) # This field type is a guess.
    _stpins = models.DateTimeField()
    _usrins = models.TextField() # This field type is a guess.
    _stpupd = models.DateTimeField()
    _usrupd = models.TextField() # This field type is a guess.
    _numver = models.IntegerField()
    _nxtrec = models.IntegerField()
    _grpusr = models.TextField() # This field type is a guess.
    _lvlsec = models.IntegerField()

    def __str__(self):
        return "[%s] %s [%s] <%s> <%s - %s>" % (self.dsddom, self.dxstyp, self.dsdpfo, self.dsddxs, self.dxsdod, self.dxsddo)

    class Meta:
        db_table = 'dsd_dxs'
        verbose_name = 'dom_x_subj'
        verbose_name_plural = 'dom_x_subjs'

    class Admin:
        list_display = ('dsddom', 'dsdpfo', 'dxsdod', 'dxsddo', 'dxstyp')

class LrrDsdDomain_x_Subject(models.Model):
    dsddxs = models.IntegerField(primary_key=True)
    dsddom = models.ForeignKey(LrrDsdDomain, db_column='dsddom')
    dsdpfo = models.ForeignKey(LrrDsdSubject, db_column='dsdpfo')
    dxsdod = models.DateField()
    dxsddo = models.DateTimeField()
    dxstyp = models.TextField(choices=domainSubjectType) # This field type is a guess.
    _stpins = models.DateTimeField()
    _usrins = models.TextField() # This field type is a guess.
    _stpupd = models.DateTimeField()
    _usrupd = models.TextField() # This field type is a guess.
    _numver = models.IntegerField()
    _nxtrec = models.IntegerField()
    _grpusr = models.TextField() # This field type is a guess.
    _lvlsec = models.IntegerField()

    def __str__(self):
        return "[%s] %s [%s] <%s> <%s - %s>" % (self.dsddom, self.dxstyp, self.dsdpfo, self.dsddxs, self.dxsdod, self.dxsddo)

    class Meta:
        db_table = 'lrr_dsd_dxs'
        verbose_name = 'dom_x_subj'
        verbose_name_plural = 'dom_x_subjs'

class DsdDns(models.Model):
    dsddns = models.IntegerField(primary_key=True)
    dsddom = models.ForeignKey(DsdDomain, db_column='dsddom')
    dnstyp = models.TextField() # This field type is a guess.
    dnsdns = models.CharField(max_length=254)
    dnsdod = models.DateTimeField()
    dnsddo = models.DateTimeField()
    _stpins = models.DateTimeField()
    _usrins = models.TextField() # This field type is a guess.
    _stpupd = models.DateTimeField()
    _usrupd = models.TextField() # This field type is a guess.
    _numver = models.IntegerField()
    _nxtrec = models.IntegerField()
    _grpusr = models.TextField() # This field type is a guess.
    _lvlsec = models.IntegerField()

    def __str__(self):
        return "%d:%s (%s) <%s - %s>" % (self.dsddns, self.dnsdns, self.dnstyp, self.dnsdod, self.dnsddo)

    class Meta:
        db_table = 'dsd_dns'
        verbose_name = 'DNS'
        verbose_name_plural = 'DNS'

    class Admin:
        pass

class LrrDsdDns(models.Model):
    dsddns = models.IntegerField(primary_key=True)
    dsddom = models.ForeignKey(LrrDsdDomain, db_column='dsddom')
    dnstyp = models.TextField() # This field type is a guess.
    dnsdns = models.CharField(max_length=254)
    dnsdod = models.DateTimeField()
    dnsddo = models.DateTimeField()
    _stpins = models.DateTimeField()
    _usrins = models.TextField() # This field type is a guess.
    _stpupd = models.DateTimeField()
    _usrupd = models.TextField() # This field type is a guess.
    _numver = models.IntegerField()
    _nxtrec = models.IntegerField()
    _grpusr = models.TextField() # This field type is a guess.
    _lvlsec = models.IntegerField()

    def __str__(self):
        return "%d:%s (%s) <%s - %s>" % (self.dsddns, self.dnsdns, self.dnstyp, self.dnsdod, self.dnsddo)

    class Meta:
        db_table = 'lrr_dsd_dns'
        verbose_name = 'DNS'
        verbose_name_plural = 'DNS'

class DsdRegistrar(models.Model):
    dsdreg = models.IntegerField(primary_key=True)
    dsdpfo = models.ForeignKey(DsdSubject, db_column='dsdpfo')
    regnam = models.TextField() # This field type is a guess.
    regval = models.CharField(max_length=254)
    regdod = models.DateField()
    regddo = models.DateField()
    _stpins = models.DateTimeField()
    _usrins = models.TextField() # This field type is a guess.
    _stpupd = models.DateTimeField()
    _usrupd = models.TextField() # This field type is a guess.
    _numver = models.IntegerField()
    _nxtrec = models.IntegerField()
    _grpusr = models.TextField() # This field type is a guess.
    _lvlsec = models.IntegerField()
    class Meta:
        db_table = 'dsd_reg'

class LrrDsdRegistrar(models.Model):
    dsdreg = models.IntegerField(primary_key=True)
    dsdpfo = models.ForeignKey(LrrDsdSubject, db_column='dsdpfo')
    regnam = models.TextField() # This field type is a guess.
    regval = models.CharField(max_length=254)
    regdod = models.DateField()
    regddo = models.DateField()
    _stpins = models.DateTimeField()
    _usrins = models.TextField() # This field type is a guess.
    _stpupd = models.DateTimeField()
    _usrupd = models.TextField() # This field type is a guess.
    _numver = models.IntegerField()
    _nxtrec = models.IntegerField()
    _grpusr = models.TextField() # This field type is a guess.
    _lvlsec = models.IntegerField()
    class Meta:
        db_table = 'lrr_dsd_reg'


class DsdParOld(models.Model):
    dsdpar = models.IntegerField(primary_key=True)
    parjme = models.TextField() # This field type is a guess.
    parval = models.CharField(max_length=254)
    parpop = models.TextField() # This field type is a guess.
    class Meta:
        db_table = 'dsd_par_old'

class DsdPpp(models.Model):
    dsdppp = models.IntegerField(primary_key=True)
    dsddom = models.ForeignKey(DsdDomain, db_column='dsddom')
    pppdcr = models.DateField()
    pppdlr = models.DateField()
    pppdvd = models.DateField()
    ppptyp = models.TextField() # This field type is a guess.
    _stpins = models.DateTimeField()
    _usrins = models.TextField() # This field type is a guess.
    _stpupd = models.DateTimeField()
    _usrupd = models.TextField() # This field type is a guess.
    _numver = models.IntegerField()
    _nxtrec = models.IntegerField()
    _grpusr = models.TextField() # This field type is a guess.
    _lvlsec = models.IntegerField()
    class Meta:
        db_table = 'dsd_ppp'

class LrrDsdPpp(models.Model):
    dsdppp = models.IntegerField(primary_key=True)
    dsddom = models.ForeignKey(LrrDsdDomain, db_column='dsddom')
    pppdcr = models.DateField()
    pppdlr = models.DateField()
    pppdvd = models.DateField()
    ppptyp = models.TextField() # This field type is a guess.
    _stpins = models.DateTimeField()
    _usrins = models.TextField() # This field type is a guess.
    _stpupd = models.DateTimeField()
    _usrupd = models.TextField() # This field type is a guess.
    _numver = models.IntegerField()
    _nxtrec = models.IntegerField()
    _grpusr = models.TextField() # This field type is a guess.
    _lvlsec = models.IntegerField()
    class Meta:
        db_table = 'lrr_dsd_ppp'

class DsdPgp(models.Model):
    dsdpgp = models.IntegerField(primary_key=True)
    dsdkon = models.ForeignKey(DsdContact, db_column='dsdkon')
    pgpdod = models.DateField()
    pgpddo = models.DateField()
    pgpkey = models.TextField() # This field type is a guess.
    _stpins = models.DateTimeField()
    _usrins = models.TextField() # This field type is a guess.
    _stpupd = models.DateTimeField()
    _usrupd = models.TextField() # This field type is a guess.
    _numver = models.IntegerField()
    _nxtrec = models.IntegerField()
    _grpusr = models.TextField() # This field type is a guess.
    _lvlsec = models.IntegerField()
    class Meta:
        db_table = 'dsd_pgp'

class LrrDsdPgp(models.Model):
    dsdpgp = models.IntegerField(primary_key=True)
    dsdkon = models.ForeignKey(LrrDsdContact, db_column='dsdkon')
    pgpdod = models.DateField()
    pgpddo = models.DateField()
    pgpkey = models.TextField() # This field type is a guess.
    _stpins = models.DateTimeField()
    _usrins = models.TextField() # This field type is a guess.
    _stpupd = models.DateTimeField()
    _usrupd = models.TextField() # This field type is a guess.
    _numver = models.IntegerField()
    _nxtrec = models.IntegerField()
    _grpusr = models.TextField() # This field type is a guess.
    _lvlsec = models.IntegerField()
    class Meta:
        db_table = 'lrr_dsd_pgp'

class DsdOtp(models.Model):
    dsdotp = models.IntegerField(primary_key=True)
    dsdkon = models.ForeignKey(DsdContact, db_column='dsdkon')
    otpdod = models.DateTimeField()
    otpddo = models.DateTimeField()
    otphas = models.TextField() # This field type is a guess.
    _stpins = models.DateTimeField()
    _usrins = models.TextField() # This field type is a guess.
    _stpupd = models.DateTimeField()
    _usrupd = models.TextField() # This field type is a guess.
    _numver = models.IntegerField()
    _nxtrec = models.IntegerField()
    _grpusr = models.TextField() # This field type is a guess.
    _lvlsec = models.IntegerField()
    class Meta:
        db_table = 'dsd_otp'

class LrrDsdOtp(models.Model):
    dsdotp = models.IntegerField(primary_key=True)
    dsdkon = models.ForeignKey(LrrDsdContact, db_column='dsdkon')
    otpdod = models.DateTimeField()
    otpddo = models.DateTimeField()
    otphas = models.TextField() # This field type is a guess.
    _stpins = models.DateTimeField()
    _usrins = models.TextField() # This field type is a guess.
    _stpupd = models.DateTimeField()
    _usrupd = models.TextField() # This field type is a guess.
    _numver = models.IntegerField()
    _nxtrec = models.IntegerField()
    _grpusr = models.TextField() # This field type is a guess.
    _lvlsec = models.IntegerField()
    class Meta:
        db_table = 'lrr_dsd_otp'

class DsdZns(models.Model):
    dsdzns = models.IntegerField(primary_key=True)
    znsjme = models.TextField() # This field type is a guess.
    attr = models.TextField() # This field type is a guess.
    values = models.CharField(max_length=254)
    _stpins = models.DateTimeField()
    _usrins = models.TextField() # This field type is a guess.
    _stpupd = models.DateTimeField()
    _usrupd = models.TextField() # This field type is a guess.
    _numver = models.IntegerField()
    _nxtrec = models.IntegerField()
    _grpusr = models.TextField() # This field type is a guess.
    _lvlsec = models.IntegerField()
    class Meta:
        db_table = 'dsd_zns'

class LrrDsdZns(models.Model):
    dsdzns = models.IntegerField(primary_key=True)
    znsjme = models.TextField() # This field type is a guess.
    attr = models.TextField() # This field type is a guess.
    values = models.CharField(max_length=254)
    _stpins = models.DateTimeField()
    _usrins = models.TextField() # This field type is a guess.
    _stpupd = models.DateTimeField()
    _usrupd = models.TextField() # This field type is a guess.
    _numver = models.IntegerField()
    _nxtrec = models.IntegerField()
    _grpusr = models.TextField() # This field type is a guess.
    _lvlsec = models.IntegerField()
    class Meta:
        db_table = 'lrr_dsd_zns'

class DsdSnaps(models.Model):
    snsid = models.IntegerField(primary_key=True)
    sname = models.TextField() # This field type is a guess.
    sgroup = models.TextField() # This field type is a guess.
    sstatus = models.TextField() # This field type is a guess.
    slen = models.IntegerField()
    smd5 = models.TextField() # This field type is a guess.
    sclen = models.IntegerField()
    scmd5 = models.TextField() # This field type is a guess.
    omask = models.TextField() # This field type is a guess.
    sdodg = models.DateTimeField()
    sddog = models.DateTimeField()
    sdod = models.DateTimeField()
    sddo = models.DateTimeField()
    scont = models.TextField() # This field type is a guess.
    _stpins = models.DateTimeField()
    _usrins = models.TextField() # This field type is a guess.
    _stpupd = models.DateTimeField()
    _usrupd = models.TextField() # This field type is a guess.
    _numver = models.IntegerField()
    _nxtrec = models.IntegerField()
    _grpusr = models.TextField() # This field type is a guess.
    _lvlsec = models.IntegerField()
    class Meta:
        db_table = 'dsd_snaps'

class LrrDsdSnaps(models.Model):
    snsid = models.IntegerField(primary_key=True)
    sname = models.TextField() # This field type is a guess.
    sgroup = models.TextField() # This field type is a guess.
    sstatus = models.TextField() # This field type is a guess.
    slen = models.IntegerField()
    smd5 = models.TextField() # This field type is a guess.
    sclen = models.IntegerField()
    scmd5 = models.TextField() # This field type is a guess.
    omask = models.TextField() # This field type is a guess.
    sdodg = models.DateTimeField()
    sddog = models.DateTimeField()
    sdod = models.DateTimeField()
    sddo = models.DateTimeField()
    scont = models.TextField() # This field type is a guess.
    _stpins = models.DateTimeField()
    _usrins = models.TextField() # This field type is a guess.
    _stpupd = models.DateTimeField()
    _usrupd = models.TextField() # This field type is a guess.
    _numver = models.IntegerField()
    _nxtrec = models.IntegerField()
    _grpusr = models.TextField() # This field type is a guess.
    _lvlsec = models.IntegerField()
    class Meta:
        db_table = 'lrr_dsd_snaps'

class DsdNss(models.Model):
    dsdnss = models.IntegerField(primary_key=True)
    nssint = models.TextField() # This field type is a guess.
    nssdur = models.TextField() # This field type is a guess.
    nssden = models.SmallIntegerField()
    nssmes = models.SmallIntegerField()
    nssrok = models.SmallIntegerField()
    nsshod = models.SmallIntegerField()
    nssmin = models.SmallIntegerField()
    nsssts = models.TextField() # This field type is a guess.
    nssins = models.SmallIntegerField()
    nssmsg = models.TextField() # This field type is a guess.
    nssqry = models.TextField() # This field type is a guess.
    nssdat = models.DateField()
    _stpins = models.DateTimeField()
    _usrins = models.TextField() # This field type is a guess.
    _stpupd = models.DateTimeField()
    _usrupd = models.TextField() # This field type is a guess.
    _numver = models.IntegerField()
    _nxtrec = models.IntegerField()
    _grpusr = models.TextField() # This field type is a guess.
    _lvlsec = models.IntegerField()
    class Meta:
        db_table = 'dsd_nss'

class DsdPky(models.Model):
    dsdpky = models.IntegerField(primary_key=True)
    dsddom = models.ForeignKey(DsdDomain, db_column='dsddom')
    pkykey = models.TextField() # This field type is a guess.
    pkydod = models.DateField()
    pkyddo = models.DateField()
    _stpins = models.DateTimeField()
    _usrins = models.TextField() # This field type is a guess.
    _stpupd = models.DateTimeField()
    _usrupd = models.TextField() # This field type is a guess.
    _numver = models.IntegerField()
    _nxtrec = models.IntegerField()
    _grpusr = models.TextField() # This field type is a guess.
    _lvlsec = models.IntegerField()
    class Meta:
        db_table = 'dsd_pky'

class LrrDsdPky(models.Model):
    dsdpky = models.IntegerField(primary_key=True)
    dsddom = models.ForeignKey(LrrDsdDomain, db_column='dsddom')
    pkykey = models.TextField() # This field type is a guess.
    pkydod = models.DateField()
    pkyddo = models.DateField()
    _stpins = models.DateTimeField()
    _usrins = models.TextField() # This field type is a guess.
    _stpupd = models.DateTimeField()
    _usrupd = models.TextField() # This field type is a guess.
    _numver = models.IntegerField()
    _nxtrec = models.IntegerField()
    _grpusr = models.TextField() # This field type is a guess.
    _lvlsec = models.IntegerField()
    class Meta:
        db_table = 'lrr_dsd_pky'

class DsdGlues(models.Model):
    dsdglu = models.IntegerField(primary_key=True)
    dsddns = models.ForeignKey(DsdDns, db_column='dsddns')
    glutyp = models.TextField() # This field type is a guess.
    gluval = models.CharField(max_length=254)
    gludod = models.DateTimeField()
    gluddo = models.DateTimeField()
    _stpins = models.DateTimeField()
    _usrins = models.TextField() # This field type is a guess.
    _stpupd = models.DateTimeField()
    _usrupd = models.TextField() # This field type is a guess.
    _numver = models.IntegerField()
    _nxtrec = models.IntegerField()
    _grpusr = models.TextField() # This field type is a guess.
    _lvlsec = models.IntegerField()
    class Meta:
        db_table = 'dsd_glu'

class LrrDsdGlues(models.Model):
    dsdglu = models.IntegerField(primary_key=True)
    dsddns = models.ForeignKey(LrrDsdDns, db_column='dsddns')
    glutyp = models.TextField() # This field type is a guess.
    gluval = models.CharField(max_length=254)
    gludod = models.DateTimeField()
    gluddo = models.DateTimeField()
    _stpins = models.DateTimeField()
    _usrins = models.TextField() # This field type is a guess.
    _stpupd = models.DateTimeField()
    _usrupd = models.TextField() # This field type is a guess.
    _numver = models.IntegerField()
    _nxtrec = models.IntegerField()
    _grpusr = models.TextField() # This field type is a guess.
    _lvlsec = models.IntegerField()
    class Meta:
        db_table = 'lrr_dsd_glu'

class DsdBlk(models.Model):
    dsdblk = models.IntegerField()
    blknam = models.CharField(max_length=254)
    blkdod = models.DateTimeField()
    blkddo = models.DateTimeField()
    _stpins = models.DateTimeField()
    _usrins = models.TextField() # This field type is a guess.
    _stpupd = models.DateTimeField()
    _usrupd = models.TextField() # This field type is a guess.
    _numver = models.IntegerField()
    _nxtrec = models.IntegerField()
    _grpusr = models.TextField() # This field type is a guess.
    _lvlsec = models.IntegerField()
    class Meta:
        db_table = 'dsd_blk'

class DsdZad(models.Model):
    dsdzad = models.IntegerField(primary_key=True)
    _stpins = models.DateTimeField()
    _usrins = models.TextField() # This field type is a guess.
    _stpupd = models.DateTimeField()
    _usrupd = models.TextField() # This field type is a guess.
    _numver = models.IntegerField()
    _nxtrec = models.IntegerField()
    _grpusr = models.TextField() # This field type is a guess.
    _lvlsec = models.IntegerField()
    class Meta:
        db_table = 'dsd_zad'

class LrrDsdZad(models.Model):
    dsdzad = models.IntegerField(primary_key=True)
    _stpins = models.DateTimeField()
    _usrins = models.TextField() # This field type is a guess.
    _stpupd = models.DateTimeField()
    _usrupd = models.TextField() # This field type is a guess.
    _numver = models.IntegerField()
    _nxtrec = models.IntegerField()
    _grpusr = models.TextField() # This field type is a guess.
    _lvlsec = models.IntegerField()
    class Meta:
        db_table = 'lrr_dsd_zad'

class DsdOza(models.Model):
    dsdoza = models.IntegerField(primary_key=True)
    dsdzad = models.ForeignKey(DsdZad, db_column='dsdzad')
    ozapor = models.SmallIntegerField()
    ozanam = models.TextField() # This field type is a guess.
    ozaval = models.CharField(max_length=254)
    _stpins = models.DateTimeField()
    _usrins = models.TextField() # This field type is a guess.
    _stpupd = models.DateTimeField()
    _usrupd = models.TextField() # This field type is a guess.
    _numver = models.IntegerField()
    _nxtrec = models.IntegerField()
    _grpusr = models.TextField() # This field type is a guess.
    _lvlsec = models.IntegerField()
    class Meta:
        db_table = 'dsd_oza'

class LrrDsdOza(models.Model):
    dsdoza = models.IntegerField(primary_key=True)
    dsdzad = models.ForeignKey(LrrDsdZad, db_column='dsdzad')
    ozapor = models.SmallIntegerField()
    ozanam = models.TextField() # This field type is a guess.
    ozaval = models.CharField(max_length=254)
    _stpins = models.DateTimeField()
    _usrins = models.TextField() # This field type is a guess.
    _stpupd = models.DateTimeField()
    _usrupd = models.TextField() # This field type is a guess.
    _numver = models.IntegerField()
    _nxtrec = models.IntegerField()
    _grpusr = models.TextField() # This field type is a guess.
    _lvlsec = models.IntegerField()
    class Meta:
        db_table = 'lrr_dsd_oza'

class DsdCis(models.Model):
    dsdcis = models.IntegerField(primary_key=True)
    cistab = models.TextField() # This field type is a guess.
    cisclo = models.TextField() # This field type is a guess.
    ciskod = models.TextField() # This field type is a guess.
    cispop = models.CharField(max_length=128)
    cisdod = models.DateTimeField()
    cisddo = models.DateTimeField()
    class Meta:
        db_table = 'dsd_cis'

class LrrDsdCis(models.Model):
    dsdcis = models.IntegerField(primary_key=True)
    cistab = models.TextField() # This field type is a guess.
    cisclo = models.TextField() # This field type is a guess.
    ciskod = models.TextField() # This field type is a guess.
    cispop = models.CharField(max_length=128)
    cisdod = models.DateTimeField()
    cisddo = models.DateTimeField()
    class Meta:
        db_table = 'lrr_dsd_cis'

class DsdMta(models.Model):
    dsdmta = models.IntegerField(primary_key=True)
    mtasrv = models.TextField(unique=True) # This field type is a guess.
    mtaldt = models.DateTimeField()
    class Meta:
        db_table = 'dsd_mta'

class LrrDsdMta(models.Model):
    dsdmta = models.IntegerField(primary_key=True)
    mtasrv = models.TextField(unique=True) # This field type is a guess.
    mtaldt = models.DateTimeField()
    class Meta:
        db_table = 'lrr_dsd_mta'

class DsdCau(models.Model):
    dsdcau = models.IntegerField(primary_key=True)
    cauisu = models.CharField(max_length=254)
    caucrl = models.CharField(max_length=140)
    cauurl = models.CharField(max_length=140)
    caudod = models.DateField()
    cauddo = models.DateField()
    caupoz = models.CharField(max_length=254)
    _stpins = models.DateTimeField()
    _usrins = models.TextField() # This field type is a guess.
    _stpupd = models.DateTimeField()
    _usrupd = models.TextField() # This field type is a guess.
    _numver = models.IntegerField()
    _nxtrec = models.IntegerField()
    _grpusr = models.TextField() # This field type is a guess.
    _lvlsec = models.IntegerField()
    class Meta:
        db_table = 'dsd_cau'

class LrrDsdCau(models.Model):
    dsdcau = models.IntegerField(primary_key=True)
    cauisu = models.CharField(max_length=254)
    caucrl = models.CharField(max_length=140)
    cauurl = models.CharField(max_length=140)
    caudod = models.DateField()
    cauddo = models.DateField()
    caupoz = models.CharField(max_length=254)
    _stpins = models.DateTimeField()
    _usrins = models.TextField() # This field type is a guess.
    _stpupd = models.DateTimeField()
    _usrupd = models.TextField() # This field type is a guess.
    _numver = models.IntegerField()
    _nxtrec = models.IntegerField()
    _grpusr = models.TextField() # This field type is a guess.
    _lvlsec = models.IntegerField()
    class Meta:
        db_table = 'lrr_dsd_cau'

class DsdCer(models.Model):
    dsdcer = models.IntegerField(primary_key=True)
    dsdcau = models.ForeignKey(DsdCau, db_column='dsdcau')
    dsdpfo = models.ForeignKey(DsdSubject, db_column='dsdpfo')
    dsdkon = models.ForeignKey(DsdContact, db_column='dsdkon')
    cerisu = models.CharField(max_length=254)
    cerser = models.CharField(max_length=60)
    cercon = models.CharField(max_length=254)
    cerorg = models.CharField(max_length=254)
    cerexp = models.DateTimeField()
    cerdod = models.DateField()
    cerddo = models.DateField()
    cerpoz = models.CharField(max_length=254)
    _stpins = models.DateTimeField()
    _usrins = models.TextField() # This field type is a guess.
    _stpupd = models.DateTimeField()
    _usrupd = models.TextField() # This field type is a guess.
    _numver = models.IntegerField()
    _nxtrec = models.IntegerField()
    _grpusr = models.TextField() # This field type is a guess.
    _lvlsec = models.IntegerField()
    class Meta:
        db_table = 'dsd_cer'

class LrrDsdCer(models.Model):
    dsdcer = models.IntegerField(primary_key=True)
    dsdcau = models.ForeignKey(LrrDsdCau, db_column='dsdcau')
    dsdpfo = models.ForeignKey(LrrDsdSubject, db_column='dsdpfo')
    dsdkon = models.ForeignKey(LrrDsdContact, db_column='dsdkon')
    cerisu = models.CharField(max_length=254)
    cerser = models.CharField(max_length=60)
    cercon = models.CharField(max_length=254)
    cerorg = models.CharField(max_length=254)
    cerexp = models.DateTimeField()
    cerdod = models.DateField()
    cerddo = models.DateField()
    cerpoz = models.CharField(max_length=254)
    _stpins = models.DateTimeField()
    _usrins = models.TextField() # This field type is a guess.
    _stpupd = models.DateTimeField()
    _usrupd = models.TextField() # This field type is a guess.
    _numver = models.IntegerField()
    _nxtrec = models.IntegerField()
    _grpusr = models.TextField() # This field type is a guess.
    _lvlsec = models.IntegerField()
    class Meta:
        db_table = 'lrr_dsd_cer'

class DsdRequest(models.Model):
    dsdreq = models.IntegerField(primary_key=True)
    dsdkon = models.ForeignKey(DsdContact, db_column='dsdkon')
    dsdpfo = models.ForeignKey(DsdSubject, db_column='dsdpfo')
    dsdcer = models.ForeignKey(DsdCer, db_column='dsdcer')
    reqdor = models.DateTimeField()
    reqdzp = models.DateTimeField()
    reqtyp = models.CharField(choices=requestTypeList, max_length=1) # This field type is a guess.
    reqidf = models.TextField(unique=True) # This field type is a guess.
    reqefr = models.CharField(max_length=128)
    reqhfr = models.CharField(max_length=128)
    reqrto = models.CharField(max_length=128)
    reqeto = models.CharField(max_length=128)
    reqhto = models.CharField(max_length=128)
    reqrpl = models.CharField(max_length=128)
    reqmid = models.CharField(max_length=254)
    reqsub = models.CharField(max_length=254)
    reqdat = models.TextField() # This field type is a guess.
    reqsts = models.TextField(choices=requestStatusList) # This field type is a guess.
    reqtob = models.CharField(max_length=20)
    reqkey = models.IntegerField()
    reqerr = models.IntegerField()
    reqctp = models.TextField() # This field type is a guess.
    reqcte = models.TextField() # This field type is a guess.
    reqcpr = models.TextField() # This field type is a guess.
    reqchs = models.TextField() # This field type is a guess.
    reqipa = models.CharField(max_length=20)
    _stpins = models.DateTimeField()
    _usrins = models.TextField() # This field type is a guess.
    _stpupd = models.DateTimeField()
    _usrupd = models.TextField() # This field type is a guess.
    _numver = models.IntegerField()
    _nxtrec = models.IntegerField()
    _grpusr = models.TextField() # This field type is a guess.
    _lvlsec = models.IntegerField()
    class Meta:
        db_table = 'dsd_req'

    def __str__(self):
        return "%d: %s %s (%s @ %s)" % (self.dsdreq, self.reqtyp, self.reqsub[:20], self.dsdpfo.pforid, self.reqdor)

class LrrDsdRequest(models.Model):
    dsdreq = models.IntegerField(primary_key=True)
    dsdkon = models.ForeignKey(LrrDsdContact, db_column='dsdkon')
    dsdpfo = models.ForeignKey(LrrDsdSubject, db_column='dsdpfo')
    dsdcer = models.ForeignKey(LrrDsdCer, db_column='dsdcer')
    reqdor = models.DateTimeField()
    reqdzp = models.DateTimeField()
    reqtyp = models.TextField(choices=requestTypeList) # This field type is a guess.
    reqidf = models.TextField(unique=True) # This field type is a guess.
    reqefr = models.CharField(max_length=128)
    reqhfr = models.CharField(max_length=128)
    reqrto = models.CharField(max_length=128)
    reqeto = models.CharField(max_length=128)
    reqhto = models.CharField(max_length=128)
    reqrpl = models.CharField(max_length=128)
    reqmid = models.CharField(max_length=254)
    reqsub = models.CharField(max_length=254)
    reqdat = models.TextField() # This field type is a guess.
    reqsts = models.TextField(choices=requestStatusList) # This field type is a guess.
    reqtob = models.CharField(max_length=20)
    reqkey = models.IntegerField()
    reqerr = models.IntegerField()
    reqctp = models.TextField() # This field type is a guess.
    reqcte = models.TextField() # This field type is a guess.
    reqcpr = models.TextField() # This field type is a guess.
    reqchs = models.TextField() # This field type is a guess.
    reqipa = models.CharField(max_length=20)
    _stpins = models.DateTimeField()
    _usrins = models.TextField() # This field type is a guess.
    _stpupd = models.DateTimeField()
    _usrupd = models.TextField() # This field type is a guess.
    _numver = models.IntegerField()
    _nxtrec = models.IntegerField()
    _grpusr = models.TextField() # This field type is a guess.
    _lvlsec = models.IntegerField()
    class Meta:
        db_table = 'lrr_dsd_req'

    def __str__(self):
        return "%d: %s %s (%s @ %s)" % (self.dsdreq, self.reqtyp, self.reqsub[:20], self.dsdpfo.pforid, self.reqdor)

class DsdPrd(models.Model):
    dsdprd = models.IntegerField(primary_key=True)
    dsdreq = models.ForeignKey(DsdRequest, db_column='dsdreq')
    prdnam = models.TextField() # This field type is a guess.
    prdval = models.CharField(max_length=254)
    _stpins = models.DateTimeField()
    _usrins = models.TextField() # This field type is a guess.
    _stpupd = models.DateTimeField()
    _usrupd = models.TextField() # This field type is a guess.
    _numver = models.IntegerField()
    _nxtrec = models.IntegerField()
    _grpusr = models.TextField() # This field type is a guess.
    _lvlsec = models.IntegerField()
    class Meta:
        db_table = 'dsd_prd'

class LrrDsdPrd(models.Model):
    dsdprd = models.IntegerField(primary_key=True)
    dsdreq = models.ForeignKey(LrrDsdRequest, db_column='dsdreq')
    prdnam = models.TextField() # This field type is a guess.
    prdval = models.CharField(max_length=254)
    _stpins = models.DateTimeField()
    _usrins = models.TextField() # This field type is a guess.
    _stpupd = models.DateTimeField()
    _usrupd = models.TextField() # This field type is a guess.
    _numver = models.IntegerField()
    _nxtrec = models.IntegerField()
    _grpusr = models.TextField() # This field type is a guess.
    _lvlsec = models.IntegerField()
    class Meta:
        db_table = 'lrr_dsd_prd'

class DsdZpr(models.Model):
    dsdzpr = models.IntegerField(primary_key=True)
    dsdreq = models.ForeignKey(DsdRequest, db_column='dsdreq')
    zprzat = models.TextField() # This field type is a guess.
    zprdat = models.DateTimeField()
    zprdod = models.DateTimeField()
    zprsts = models.TextField() # This field type is a guess.
    zprtxt = models.TextField() # This field type is a guess.
    zprhas = models.CharField(max_length=32)
    _stpins = models.DateTimeField()
    _usrins = models.TextField() # This field type is a guess.
    _stpupd = models.DateTimeField()
    _usrupd = models.TextField() # This field type is a guess.
    _numver = models.IntegerField()
    _nxtrec = models.IntegerField()
    _grpusr = models.TextField() # This field type is a guess.
    _lvlsec = models.IntegerField()
    class Meta:
        db_table = 'dsd_zpr'

class LrrDsdZpr(models.Model):
    dsdzpr = models.IntegerField(primary_key=True)
    dsdreq = models.ForeignKey(LrrDsdRequest, db_column='dsdreq')
    zprzat = models.TextField() # This field type is a guess.
    zprdat = models.DateTimeField()
    zprdod = models.DateTimeField()
    zprsts = models.TextField() # This field type is a guess.
    zprtxt = models.TextField() # This field type is a guess.
    zprhas = models.CharField(max_length=32)
    _stpins = models.DateTimeField()
    _usrins = models.TextField() # This field type is a guess.
    _stpupd = models.DateTimeField()
    _usrupd = models.TextField() # This field type is a guess.
    _numver = models.IntegerField()
    _nxtrec = models.IntegerField()
    _grpusr = models.TextField() # This field type is a guess.
    _lvlsec = models.IntegerField()
    class Meta:
        db_table = 'lrr_dsd_zpr'

class DsdX2D(models.Model):
    dsdx2d = models.IntegerField(primary_key=True)
    x2dtyp = models.TextField() # This field type is a guess.
    x2dxml = models.TextField(unique=True) # This field type is a guess.
    x2ddbs = models.TextField() # This field type is a guess.
    class Meta:
        db_table = 'dsd_x2d'

class LrrDsdX2D(models.Model):
    dsdx2d = models.IntegerField(primary_key=True)
    x2dtyp = models.TextField() # This field type is a guess.
    x2dxml = models.TextField(unique=True) # This field type is a guess.
    x2ddbs = models.TextField() # This field type is a guess.
    class Meta:
        db_table = 'lrr_dsd_x2d'

class History(models.Model):
    hishis = models.IntegerField(primary_key=True)
    histab = models.TextField() # This field type is a guess.
    hiscol = models.TextField() # This field type is a guess.
    hiskey = models.IntegerField()
    hisval = models.CharField(max_length=255)
    hisstp = models.DateTimeField()
    hisusr = models.TextField() # This field type is a guess.
    _stpins = models.DateTimeField()
    _usrins = models.TextField() # This field type is a guess.
    _stpupd = models.DateTimeField()
    _usrupd = models.TextField() # This field type is a guess.
    _numver = models.IntegerField()
    _nxtrec = models.IntegerField()
    class Meta:
        db_table = 'gen_his'

    def __str__(self):
        return "%s/%s/%s -> %s [%s]" % (str(self.histab).strip(), 
                                        str(self.hiscol).strip(), 
                                        str(self.hiskey), 
                                        str(self.hisval).strip(), self.hisstp)

class LrrHistory(models.Model):
    hishis = models.IntegerField(primary_key=True)
    histab = models.TextField() # This field type is a guess.
    hiscol = models.TextField() # This field type is a guess.
    hiskey = models.IntegerField()
    hisval = models.CharField(max_length=255)
    hisstp = models.DateTimeField()
    hisusr = models.TextField() # This field type is a guess.
    _stpins = models.DateTimeField()
    _usrins = models.TextField() # This field type is a guess.
    _stpupd = models.DateTimeField()
    _usrupd = models.TextField() # This field type is a guess.
    _numver = models.IntegerField()
    _nxtrec = models.IntegerField()
    class Meta:
        db_table = 'lrr_gen_his'

    def __str__(self):
        return "%s/%s/%s -> %s [%s]" % (str(self.histab).strip(), 
                                        str(self.hiscol).strip(), 
                                        str(self.hiskey), 
                                        str(self.hisval).strip(), self.hisstp)

class DsdAns(models.Model):
    dsdans = models.IntegerField(primary_key=True)
    dsdreq = models.ForeignKey(DsdRequest, db_column='dsdreq')
    dsdpfo = models.ForeignKey(DsdSubject, db_column='dsdpfo')
    anskod = models.SmallIntegerField()
    ansout = models.TextField() # This field type is a guess.
    anssnd = models.TextField() # This field type is a guess.
    ansoid = models.IntegerField()
    reqidf = models.CharField(max_length=254)
    _stpins = models.DateTimeField()
    _usrins = models.TextField() # This field type is a guess.
    _stpupd = models.DateTimeField()
    _usrupd = models.TextField() # This field type is a guess.
    _numver = models.IntegerField()
    _nxtrec = models.IntegerField()
    _grpusr = models.TextField() # This field type is a guess.
    _lvlsec = models.IntegerField()
    class Meta:
        db_table = 'dsd_ans'

class DsdZmb(models.Model):
    dsdzmb = models.IntegerField()
    dsddom = models.ForeignKey(DsdDomain, db_column='dsddom')
    regdate = models.DateTimeField()
    expdate = models.DateTimeField()
    class Meta:
        db_table = 'dsd_zmb'

class LrrDsdZmb(models.Model):
    dsdzmb = models.IntegerField()
    dsddom = models.ForeignKey(LrrDsdDomain, db_column='dsddom')
    regdate = models.DateTimeField()
    expdate = models.DateTimeField()
    class Meta:
        db_table = 'lrr_dsd_zmb'

class DsdTet(models.Model):
    dsdtet = models.IntegerField(primary_key=True)
    dsddom = models.ForeignKey(DsdDomain, db_column='dsddom', blank=True, null=True)
    dsdreq = models.ForeignKey(DsdRequest, db_column='dsdreq', blank=True, null=True)
    dsdpfo = models.ForeignKey(DsdSubject, db_column='dsdpfo')
    tetnsg = models.TextField() # This field type is a guess.
    tetclr = models.CharField(max_length=128)
    tetpky = models.TextField() # This field type is a guess.
    ptype = models.TextField(choices=techtestTypeList) # This field type is a guess.
    tout = models.TextField(choices=techtestFormatList) # This field type is a guess.
    msent = models.TextField(choices=techtestDataList) # This field type is a guess.
    lres = models.TextField(choices=techtestResultList) # This field type is a guess.
    tnum = models.SmallIntegerField()
    regdate = models.DateTimeField()
    expdate = models.DateTimeField()
    tetemt = models.CharField(max_length=64)
    _stpins = models.DateTimeField()
    _usrins = models.TextField() # This field type is a guess.
    _stpupd = models.DateTimeField()
    _usrupd = models.TextField() # This field type is a guess.
    _numver = models.IntegerField()
    _nxtrec = models.IntegerField()
    _grpusr = models.TextField() # This field type is a guess.
    _lvlsec = models.IntegerField()
    class Meta:
        db_table = 'dsd_tet'

class LrrDsdTet(models.Model):
    dsdtet = models.IntegerField(primary_key=True)
    dsddom = models.ForeignKey(LrrDsdDomain, db_column='dsddom')
    dsdreq = models.ForeignKey(LrrDsdRequest, db_column='dsdreq')
    dsdpfo = models.ForeignKey(LrrDsdSubject, db_column='dsdpfo')
    tetnsg = models.TextField() # This field type is a guess.
    tetclr = models.CharField(max_length=128)
    tetpky = models.TextField() # This field type is a guess.
    ptype = models.TextField() # This field type is a guess.
    tout = models.TextField() # This field type is a guess.
    msent = models.TextField() # This field type is a guess.
    lres = models.TextField() # This field type is a guess.
    tnum = models.SmallIntegerField()
    regdate = models.DateTimeField()
    expdate = models.DateTimeField()
    tetemt = models.CharField(max_length=64)
    _stpins = models.DateTimeField()
    _usrins = models.TextField() # This field type is a guess.
    _stpupd = models.DateTimeField()
    _usrupd = models.TextField() # This field type is a guess.
    _numver = models.IntegerField()
    _nxtrec = models.IntegerField()
    _grpusr = models.TextField() # This field type is a guess.
    _lvlsec = models.IntegerField()
    class Meta:
        db_table = 'lrr_dsd_tet'

class DsdQit(models.Model):
    dsdqit = models.IntegerField(primary_key=True)
    dsdtet = models.ForeignKey(DsdTet, db_column='dsdtet')
    errstr = models.TextField() # This field type is a guess.
    errtxt = models.TextField() # This field type is a guess.
    msent = models.TextField() # This field type is a guess.
    tstdate = models.DateTimeField()
    class Meta:
        db_table = 'dsd_qit'

class DsdTldcodes(models.Model):
    tld = models.CharField(max_length=64)
    name = models.CharField(max_length=254)
    class Meta:
        db_table = 'dsd_tldcodes'

class GenCis(models.Model):
    gencis = models.IntegerField(primary_key=True)
    cistab = models.TextField() # This field type is a guess.
    cisrok = models.SmallIntegerField()
    ciscis = models.IntegerField()
    _stpins = models.DateTimeField()
    _usrins = models.TextField() # This field type is a guess.
    _stpupd = models.DateTimeField()
    _usrupd = models.TextField() # This field type is a guess.
    _numver = models.IntegerField()
    _nxtrec = models.IntegerField()
    class Meta:
        db_table = 'gen_cis'

class LrrGenCis(models.Model):
    gencis = models.IntegerField(primary_key=True)
    cistab = models.TextField() # This field type is a guess.
    cisrok = models.SmallIntegerField()
    ciscis = models.IntegerField()
    _stpins = models.DateTimeField()
    _usrins = models.TextField() # This field type is a guess.
    _stpupd = models.DateTimeField()
    _usrupd = models.TextField() # This field type is a guess.
    _numver = models.IntegerField()
    _nxtrec = models.IntegerField()
    class Meta:
        db_table = 'lrr_gen_cis'

class DsdPrl(models.Model):
    dsdprl = models.IntegerField(primary_key=True)
    dsdprd = models.IntegerField()
    prlval = models.TextField() # This field type is a guess.
    class Meta:
        db_table = 'dsd_prl'

class LrrDsdPrl(models.Model):
    dsdprl = models.IntegerField(primary_key=True)
    dsdprd = models.IntegerField()
    prlval = models.TextField() # This field type is a guess.
    class Meta:
        db_table = 'lrr_dsd_prl'

class DsdSmr(models.Model):
    dsdsmr = models.IntegerField(primary_key=True)
    smrpgn = models.CharField(max_length=20)
    smrprn = models.CharField(max_length=20)
    smrdex = models.DateTimeField()
    smrsts = models.TextField() # This field type is a guess.
    smrkod = models.IntegerField()
    smrtyp = models.TextField() # This field type is a guess.
    _stpins = models.DateTimeField()
    _usrins = models.TextField() # This field type is a guess.
    _stpupd = models.DateTimeField()
    _usrupd = models.TextField() # This field type is a guess.
    _numver = models.IntegerField()
    _nxtrec = models.IntegerField()
    _grpusr = models.TextField() # This field type is a guess.
    _lvlsec = models.IntegerField()
    class Meta:
        db_table = 'dsd_smr'

class LrrDsdSmr(models.Model):
    dsdsmr = models.IntegerField(primary_key=True)
    smrpgn = models.CharField(max_length=20)
    smrprn = models.CharField(max_length=20)
    smrdex = models.DateTimeField()
    smrsts = models.TextField() # This field type is a guess.
    smrkod = models.IntegerField()
    smrtyp = models.TextField() # This field type is a guess.
    _stpins = models.DateTimeField()
    _usrins = models.TextField() # This field type is a guess.
    _stpupd = models.DateTimeField()
    _usrupd = models.TextField() # This field type is a guess.
    _numver = models.IntegerField()
    _nxtrec = models.IntegerField()
    _grpusr = models.TextField() # This field type is a guess.
    _lvlsec = models.IntegerField()
    class Meta:
        db_table = 'lrr_dsd_smr'

class DsdSmp(models.Model):
    dsdsmp = models.IntegerField(primary_key=True)
    dsdsmr = models.ForeignKey(DsdSmr, db_column='dsdsmr')
    smpnam = models.CharField(max_length=32)
    smpval = models.CharField(max_length=254)
    _stpins = models.DateTimeField()
    _usrins = models.TextField() # This field type is a guess.
    _stpupd = models.DateTimeField()
    _usrupd = models.TextField() # This field type is a guess.
    _numver = models.IntegerField()
    _nxtrec = models.IntegerField()
    _grpusr = models.TextField() # This field type is a guess.
    _lvlsec = models.IntegerField()
    class Meta:
        db_table = 'dsd_smp'

class LrrDsdSmp(models.Model):
    dsdsmp = models.IntegerField(primary_key=True)
    dsdsmr = models.ForeignKey(LrrDsdSmr, db_column='dsdsmr')
    smpnam = models.CharField(max_length=32)
    smpval = models.CharField(max_length=254)
    _stpins = models.DateTimeField()
    _usrins = models.TextField() # This field type is a guess.
    _stpupd = models.DateTimeField()
    _usrupd = models.TextField() # This field type is a guess.
    _numver = models.IntegerField()
    _nxtrec = models.IntegerField()
    _grpusr = models.TextField() # This field type is a guess.
    _lvlsec = models.IntegerField()
    class Meta:
        db_table = 'lrr_dsd_smp'

class DsdSmi(models.Model):
    dsdsmi = models.IntegerField(primary_key=True)
    dsdsmr = models.ForeignKey(DsdSmr, db_column='dsdsmr')
    smitob = models.CharField(max_length=32)
    smikey = models.IntegerField()
    _stpins = models.DateTimeField()
    _usrins = models.TextField() # This field type is a guess.
    _stpupd = models.DateTimeField()
    _usrupd = models.TextField() # This field type is a guess.
    _numver = models.IntegerField()
    _nxtrec = models.IntegerField()
    _grpusr = models.TextField() # This field type is a guess.
    _lvlsec = models.IntegerField()
    class Meta:
        db_table = 'dsd_smi'

class LrrDsdSmi(models.Model):
    dsdsmi = models.IntegerField(primary_key=True)
    dsdsmr = models.ForeignKey(LrrDsdSmr, db_column='dsdsmr')
    smitob = models.CharField(max_length=32)
    smikey = models.IntegerField()
    _stpins = models.DateTimeField()
    _usrins = models.TextField() # This field type is a guess.
    _stpupd = models.DateTimeField()
    _usrupd = models.TextField() # This field type is a guess.
    _numver = models.IntegerField()
    _nxtrec = models.IntegerField()
    _grpusr = models.TextField() # This field type is a guess.
    _lvlsec = models.IntegerField()
    class Meta:
        db_table = 'lrr_dsd_smi'

class DsdSmv(models.Model):
    dsdsmv = models.IntegerField(primary_key=True)
    dsdsmr = models.ForeignKey(DsdSmr, db_column='dsdsmr')
    smvkod = models.TextField() # This field type is a guess.
    smvval = models.CharField(max_length=64)
    _stpins = models.DateTimeField()
    _usrins = models.TextField() # This field type is a guess.
    _stpupd = models.DateTimeField()
    _usrupd = models.TextField() # This field type is a guess.
    _numver = models.IntegerField()
    _nxtrec = models.IntegerField()
    _grpusr = models.TextField() # This field type is a guess.
    _lvlsec = models.IntegerField()
    class Meta:
        db_table = 'dsd_smv'

class LrrDsdSmv(models.Model):
    dsdsmv = models.IntegerField(primary_key=True)
    dsdsmr = models.ForeignKey(LrrDsdSmr, db_column='dsdsmr')
    smvkod = models.TextField() # This field type is a guess.
    smvval = models.CharField(max_length=64)
    _stpins = models.DateTimeField()
    _usrins = models.TextField() # This field type is a guess.
    _stpupd = models.DateTimeField()
    _usrupd = models.TextField() # This field type is a guess.
    _numver = models.IntegerField()
    _nxtrec = models.IntegerField()
    _grpusr = models.TextField() # This field type is a guess.
    _lvlsec = models.IntegerField()
    class Meta:
        db_table = 'lrr_dsd_smv'

class DsdZmb1(models.Model):
    dsdzmb = models.IntegerField()
    dsddom = models.ForeignKey(DsdDomain, db_column='dsddom')
    regdate = models.DateTimeField()
    expdate = models.DateTimeField()
    class Meta:
        db_table = 'dsd_zmb1'

class DsdUpo(models.Model):
    dsdupo = models.IntegerField(primary_key=True)
    upodcr = models.DateField()
    upodlr = models.DateField()
    upodvd = models.DateField()
    upopoc = models.SmallIntegerField()
    upoper = models.SmallIntegerField()
    upotyp = models.TextField() # This field type is a guess.
    _stpins = models.DateTimeField()
    _usrins = models.TextField() # This field type is a guess.
    _stpupd = models.DateTimeField()
    _usrupd = models.TextField() # This field type is a guess.
    _numver = models.IntegerField()
    _nxtrec = models.IntegerField()
    _grpusr = models.TextField() # This field type is a guess.
    _lvlsec = models.IntegerField()
    class Meta:
        db_table = 'dsd_upo'

class DsdPdo(models.Model):
    dsdpdo = models.IntegerField(primary_key=True)
    dsdupo = models.ForeignKey(DsdUpo, db_column='dsdupo')
    pdonaz = models.CharField(max_length=254)
    pdomis = models.CharField(max_length=254)
    pdouli = models.CharField(max_length=254)
    pdopsc = models.TextField() # This field type is a guess.
    pdosta = models.TextField() # This field type is a guess.
    dsdadr = models.IntegerField()
    dsderr = models.SmallIntegerField()
    _stpins = models.DateTimeField()
    _usrins = models.TextField() # This field type is a guess.
    _stpupd = models.DateTimeField()
    _usrupd = models.TextField() # This field type is a guess.
    _numver = models.IntegerField()
    _nxtrec = models.IntegerField()
    _grpusr = models.TextField() # This field type is a guess.
    _lvlsec = models.IntegerField()
    class Meta:
        db_table = 'dsd_pdo'

class DsdDdd(models.Model):
    dsdddd = models.IntegerField(primary_key=True)
    dsdpdo = models.ForeignKey(DsdPdo, db_column='dsdpdo')
    ddddom = models.IntegerField()
    _stpins = models.DateTimeField()
    _usrins = models.TextField() # This field type is a guess.
    _stpupd = models.DateTimeField()
    _usrupd = models.TextField() # This field type is a guess.
    _numver = models.IntegerField()
    _nxtrec = models.IntegerField()
    _grpusr = models.TextField() # This field type is a guess.
    _lvlsec = models.IntegerField()
    class Meta:
        db_table = 'dsd_ddd'

class DsdSrr(models.Model):
    dsdsrr = models.IntegerField(primary_key=True)
    srrpol = models.SmallIntegerField()
    srrctv = models.SmallIntegerField()
    srrden = models.SmallIntegerField()
    srrrok = models.SmallIntegerField()
    srrmes = models.SmallIntegerField()
    srrtyp = models.TextField() # This field type is a guess.
    srrsum = models.IntegerField()
    srrdat = models.DateField()
    _stpins = models.DateTimeField()
    _usrins = models.TextField() # This field type is a guess.
    _stpupd = models.DateTimeField()
    _usrupd = models.TextField() # This field type is a guess.
    _numver = models.IntegerField()
    _nxtrec = models.IntegerField()
    class Meta:
        db_table = 'dsd_srr'

class DsdDdr(models.Model):
    dsdddr = models.IntegerField(primary_key=True)
    dsdpfo = models.ForeignKey(DsdSubject, db_column='dsdpfo')
    ddrrok = models.SmallIntegerField()
    ddrmes = models.SmallIntegerField()
    ddrcfa = models.TextField() # This field type is a guess.
    ddrico = models.TextField() # This field type is a guess.
    ddrsts = models.TextField() # This field type is a guess.
    ddrcas = models.DecimalField(max_digits=13, decimal_places=2)
    _stpins = models.DateTimeField()
    _usrins = models.TextField() # This field type is a guess.
    _stpupd = models.DateTimeField()
    _usrupd = models.TextField() # This field type is a guess.
    _numver = models.IntegerField()
    _nxtrec = models.IntegerField()
    _grpusr = models.TextField() # This field type is a guess.
    _lvlsec = models.IntegerField()
    class Meta:
        db_table = 'dsd_ddr'

class DsdDrb(models.Model):
    dsddrb = models.IntegerField(primary_key=True)
    dsdddr = models.ForeignKey(DsdDdr, db_column='dsdddr')
    drbtyp = models.SmallIntegerField()
    drbblb = models.TextField() # This field type is a guess.
    _stpins = models.DateTimeField()
    _usrins = models.TextField() # This field type is a guess.
    _stpupd = models.DateTimeField()
    _usrupd = models.TextField() # This field type is a guess.
    _numver = models.IntegerField()
    _nxtrec = models.IntegerField()
    _grpusr = models.TextField() # This field type is a guess.
    _lvlsec = models.IntegerField()
    class Meta:
        db_table = 'dsd_drb'

class DsdSre(models.Model):
    dsdsre = models.IntegerField(primary_key=True)
    srepol = models.SmallIntegerField()
    srectv = models.SmallIntegerField()
    sreden = models.SmallIntegerField()
    srerok = models.SmallIntegerField()
    sremes = models.SmallIntegerField()
    sretyp = models.TextField() # This field type is a guess.
    srests = models.SmallIntegerField()
    sresum = models.IntegerField()
    sredat = models.DateField()
    _stpins = models.DateTimeField()
    _usrins = models.TextField() # This field type is a guess.
    _stpupd = models.DateTimeField()
    _usrupd = models.TextField() # This field type is a guess.
    _numver = models.IntegerField()
    _nxtrec = models.IntegerField()
    class Meta:
        db_table = 'dsd_sre'

class DsdSpd(models.Model):
    dsdspd = models.IntegerField(primary_key=True)
    spdpol = models.SmallIntegerField()
    spdctv = models.SmallIntegerField()
    spdden = models.SmallIntegerField()
    spdrok = models.SmallIntegerField()
    spdmes = models.SmallIntegerField()
    spdtyp = models.TextField() # This field type is a guess.
    spdsum = models.IntegerField()
    spddat = models.DateField()
    _stpins = models.DateTimeField()
    _usrins = models.TextField() # This field type is a guess.
    _stpupd = models.DateTimeField()
    _usrupd = models.TextField() # This field type is a guess.
    _numver = models.IntegerField()
    _nxtrec = models.IntegerField()
    class Meta:
        db_table = 'dsd_spd'

class DsdSrg(models.Model):
    dsdsrg = models.IntegerField(primary_key=True)
    srgpol = models.SmallIntegerField()
    srgctv = models.SmallIntegerField()
    srgden = models.SmallIntegerField()
    srgrok = models.SmallIntegerField()
    srgmes = models.SmallIntegerField()
    srgtyp = models.IntegerField()
    srgsum = models.IntegerField()
    srgdat = models.DateField()
    _stpins = models.DateTimeField()
    _usrins = models.TextField() # This field type is a guess.
    _stpupd = models.DateTimeField()
    _usrupd = models.TextField() # This field type is a guess.
    _numver = models.IntegerField()
    _nxtrec = models.IntegerField()
    class Meta:
        db_table = 'dsd_srg'

class DsdSos(models.Model):
    dsdsos = models.IntegerField(primary_key=True)
    sospol = models.SmallIntegerField()
    sosctv = models.SmallIntegerField()
    sosden = models.SmallIntegerField()
    sosrok = models.SmallIntegerField()
    sosmes = models.SmallIntegerField()
    sostyp = models.TextField() # This field type is a guess.
    sossum = models.IntegerField()
    sosdat = models.DateField()
    _stpins = models.DateTimeField()
    _usrins = models.TextField() # This field type is a guess.
    _stpupd = models.DateTimeField()
    _usrupd = models.TextField() # This field type is a guess.
    _numver = models.IntegerField()
    _nxtrec = models.IntegerField()
    class Meta:
        db_table = 'dsd_sos'

class DsdSpo(models.Model):
    dsdspo = models.IntegerField(primary_key=True)
    spopol = models.SmallIntegerField()
    spoctv = models.SmallIntegerField()
    spoden = models.SmallIntegerField()
    sporok = models.SmallIntegerField()
    spomes = models.SmallIntegerField()
    spotyp = models.TextField() # This field type is a guess.
    sposts = models.SmallIntegerField()
    sposum = models.IntegerField()
    spodat = models.DateField()
    _stpins = models.DateTimeField()
    _usrins = models.TextField() # This field type is a guess.
    _stpupd = models.DateTimeField()
    _usrupd = models.TextField() # This field type is a guess.
    _numver = models.IntegerField()
    _nxtrec = models.IntegerField()
    class Meta:
        db_table = 'dsd_spo'

class DsdSfa(models.Model):
    dsdsfa = models.IntegerField(primary_key=True)
    sfapol = models.SmallIntegerField()
    sfactv = models.SmallIntegerField()
    sfaden = models.SmallIntegerField()
    sfarok = models.SmallIntegerField()
    sfames = models.SmallIntegerField()
    sfatyp = models.TextField() # This field type is a guess.
    sfakod = models.TextField() # This field type is a guess.
    sfasum = models.IntegerField()
    sfadat = models.DateField()
    _stpins = models.DateTimeField()
    _usrins = models.TextField() # This field type is a guess.
    _stpupd = models.DateTimeField()
    _usrupd = models.TextField() # This field type is a guess.
    _numver = models.IntegerField()
    _nxtrec = models.IntegerField()
    class Meta:
        db_table = 'dsd_sfa'

class DsdCst(models.Model):
    dsdsta = models.IntegerField(primary_key=True)
    stakod = models.TextField() # This field type is a guess.
    staseu = models.TextField() # This field type is a guess.
    stanaz = models.CharField(max_length=254)
    class Meta:
        db_table = 'dsd_cst'

class DsdPra(models.Model):
    dsdpra = models.IntegerField(primary_key=True)
    praver = models.TextField() # This field type is a guess.
    pratyp = models.TextField() # This field type is a guess.
    pradod = models.DateField()
    praddo = models.DateField()
    _stpins = models.DateTimeField()
    _usrins = models.TextField() # This field type is a guess.
    _stpupd = models.DateTimeField()
    _usrupd = models.TextField() # This field type is a guess.
    _numver = models.IntegerField()
    _nxtrec = models.IntegerField()
    _grpusr = models.TextField() # This field type is a guess.
    _lvlsec = models.IntegerField()
    class Meta:
        db_table = 'dsd_pra'

class LrrDsdPra(models.Model):
    dsdpra = models.IntegerField(primary_key=True)
    praver = models.TextField() # This field type is a guess.
    pratyp = models.TextField() # This field type is a guess.
    pradod = models.DateField()
    praddo = models.DateField()
    _stpins = models.DateTimeField()
    _usrins = models.TextField() # This field type is a guess.
    _stpupd = models.DateTimeField()
    _usrupd = models.TextField() # This field type is a guess.
    _numver = models.IntegerField()
    _nxtrec = models.IntegerField()
    _grpusr = models.TextField() # This field type is a guess.
    _lvlsec = models.IntegerField()
    class Meta:
        db_table = 'lrr_dsd_pra'

class DsdObp(models.Model):
    dsdobp = models.IntegerField(primary_key=True)
    dsdpra = models.ForeignKey(DsdPra, db_column='dsdpra')
    obptyp = models.TextField() # This field type is a guess.
    obpblb = models.TextField() # This field type is a guess.
    _stpins = models.DateTimeField()
    _usrins = models.TextField() # This field type is a guess.
    _stpupd = models.DateTimeField()
    _usrupd = models.TextField() # This field type is a guess.
    _numver = models.IntegerField()
    _nxtrec = models.IntegerField()
    _grpusr = models.TextField() # This field type is a guess.
    _lvlsec = models.IntegerField()
    class Meta:
        db_table = 'dsd_obp'

class LrrDsdObp(models.Model):
    dsdobp = models.IntegerField(primary_key=True)
    dsdpra = models.ForeignKey(LrrDsdPra, db_column='dsdpra')
    obptyp = models.TextField() # This field type is a guess.
    obpblb = models.TextField() # This field type is a guess.
    _stpins = models.DateTimeField()
    _usrins = models.TextField() # This field type is a guess.
    _stpupd = models.DateTimeField()
    _usrupd = models.TextField() # This field type is a guess.
    _numver = models.IntegerField()
    _nxtrec = models.IntegerField()
    _grpusr = models.TextField() # This field type is a guess.
    _lvlsec = models.IntegerField()
    class Meta:
        db_table = 'lrr_dsd_obp'

class DsdSto(models.Model):
    dsdsto = models.IntegerField(primary_key=True)
    dsddom = models.ForeignKey(DsdDomain, db_column='dsddom')
    stotyp = models.TextField() # This field type is a guess.
    stosts = models.TextField() # This field type is a guess.
    dsdsmr = models.ForeignKey(DsdSmr, db_column='dsdsmr')
    _stpins = models.DateTimeField()
    _usrins = models.TextField() # This field type is a guess.
    _stpupd = models.DateTimeField()
    _usrupd = models.TextField() # This field type is a guess.
    _numver = models.IntegerField()
    _nxtrec = models.IntegerField()
    _grpusr = models.TextField() # This field type is a guess.
    _lvlsec = models.IntegerField()
    class Meta:
        db_table = 'dsd_sto'

class DsdCnv(models.Model):
    dsdcnv = models.IntegerField(primary_key=True)
    cnvtab = models.TextField() # This field type is a guess.
    cnvcol = models.TextField() # This field type is a guess.
    cnvkey = models.IntegerField()
    cnvold = models.CharField(max_length=254)
    cnvnew = models.CharField(max_length=254)
    cnvdat = models.DateTimeField()
    cnvcda = models.IntegerField()
    _stpins = models.DateTimeField()
    _usrins = models.TextField() # This field type is a guess.
    _stpupd = models.DateTimeField()
    _usrupd = models.TextField() # This field type is a guess.
    _numver = models.IntegerField()
    _nxtrec = models.IntegerField()
    class Meta:
        db_table = 'dsd_cnv'

class LrrDsdCnv(models.Model):
    dsdcnv = models.IntegerField(primary_key=True)
    cnvtab = models.TextField() # This field type is a guess.
    cnvcol = models.TextField() # This field type is a guess.
    cnvkey = models.IntegerField()
    cnvold = models.CharField(max_length=254)
    cnvnew = models.CharField(max_length=254)
    cnvdat = models.DateTimeField()
    cnvcda = models.IntegerField()
    _stpins = models.DateTimeField()
    _usrins = models.TextField() # This field type is a guess.
    _stpupd = models.DateTimeField()
    _usrupd = models.TextField() # This field type is a guess.
    _numver = models.IntegerField()
    _nxtrec = models.IntegerField()
    class Meta:
        db_table = 'lrr_dsd_cnv'

class DsdPfp(models.Model):
    dsdpfp = models.IntegerField(primary_key=True)
    pfpjme = models.TextField() # This field type is a guess.
    pfpval = models.CharField(max_length=254)
    pfppop = models.TextField() # This field type is a guess.
    pfpdod = models.DateField()
    pfpddo = models.DateField()
    class Meta:
        db_table = 'dsd_pfp'

class LrrDsdPfp(models.Model):
    dsdpfp = models.IntegerField(primary_key=True)
    pfpjme = models.TextField() # This field type is a guess.
    pfpval = models.CharField(max_length=254)
    pfppop = models.TextField() # This field type is a guess.
    pfpdod = models.DateField()
    pfpddo = models.DateField()
    class Meta:
        db_table = 'lrr_dsd_pfp'

class DsdCre(models.Model):
    dsdcre = models.IntegerField(primary_key=True)
    dsdpfo = models.ForeignKey(DsdSubject, db_column='dsdpfo')
    crecre = models.DecimalField(max_digits=15, decimal_places=2)
    crecor = models.DecimalField(max_digits=15, decimal_places=2)
    creact = models.DecimalField(max_digits=15, decimal_places=2)
    creusr = models.TextField() # This field type is a guess.
    crepls = models.DecimalField(max_digits=15, decimal_places=2)
    cretim = models.DateTimeField()
    _stpins = models.DateTimeField()
    _usrins = models.TextField() # This field type is a guess.
    _stpupd = models.DateTimeField()
    _usrupd = models.TextField() # This field type is a guess.
    _numver = models.IntegerField()
    _nxtrec = models.IntegerField()
    _grpusr = models.TextField() # This field type is a guess.
    _lvlsec = models.IntegerField()
    class Meta:
        db_table = 'dsd_cre'

class DsdOut(models.Model):
    dsdout = models.IntegerField(primary_key=True)
    mto = models.CharField(max_length=254)
    mfrom = models.CharField(max_length=64)
    mfromadr = models.CharField(max_length=64)
    msubject = models.CharField(max_length=64)
    mreplyto = models.CharField(max_length=64)
    mid = models.CharField(max_length=254)
    mbcc = models.CharField(max_length=64)
    mcc = models.CharField(max_length=54)
    mbody = models.TextField() # This field type is a guess.
    mdate = models.DateTimeField()
    mstatus = models.TextField() # This field type is a guess.
    msrc = models.CharField(max_length=80)
    mgrp = models.TextField() # This field type is a guess.
    outtim = models.DateTimeField()
    outsts = models.TextField() # This field type is a guess.
    outtxt = models.CharField(max_length=128)
    outsrc = models.CharField(max_length=20)
    outkey = models.IntegerField()
    outtpl = models.CharField(max_length=32)
    outxid = models.CharField(max_length=254)
    outtpd = models.DateTimeField()
    _stpins = models.DateTimeField()
    _usrins = models.TextField() # This field type is a guess.
    _stpupd = models.DateTimeField()
    _usrupd = models.TextField() # This field type is a guess.
    _numver = models.IntegerField()
    _nxtrec = models.IntegerField()
    _grpusr = models.TextField() # This field type is a guess.
    _lvlsec = models.IntegerField()
    class Meta:
        db_table = 'dsd_out'

class TestDsdOut(models.Model):
    dsdout = models.IntegerField(primary_key=True)
    dsdtyp = models.CharField(max_length=3)
    mto = models.CharField(max_length=254)
    mfrom = models.CharField(max_length=64)
    mfromadr = models.CharField(max_length=64)
    msubject = models.CharField(max_length=64)
    mreplyto = models.CharField(max_length=64)
    mid = models.CharField(max_length=254)
    mbcc = models.CharField(max_length=64)
    mcc = models.CharField(max_length=54)
    mbody = models.TextField() # This field type is a guess.
    mdate = models.DateTimeField()
    mstatus = models.TextField() # This field type is a guess.
    msrc = models.CharField(max_length=80)
    mgrp = models.TextField() # This field type is a guess.
    outtim = models.DateTimeField()
    outsts = models.TextField() # This field type is a guess.
    outtxt = models.CharField(max_length=128)
    outsrc = models.CharField(max_length=20)
    outkey = models.IntegerField()
    outtpl = models.CharField(max_length=32)
    outxid = models.CharField(max_length=254)
    outtpd = models.DateTimeField()
    _stpins = models.DateTimeField()
    _usrins = models.TextField() # This field type is a guess.
    _stpupd = models.DateTimeField()
    _usrupd = models.TextField() # This field type is a guess.
    _numver = models.IntegerField()
    _nxtrec = models.IntegerField()
    _grpusr = models.TextField() # This field type is a guess.
    _lvlsec = models.IntegerField()
    class Meta:
        db_table = 'test_req_out'

class LrrDsdOut(models.Model):
    dsdout = models.IntegerField(primary_key=True)
    mto = models.CharField(max_length=254)
    mfrom = models.CharField(max_length=64)
    mfromadr = models.CharField(max_length=64)
    msubject = models.CharField(max_length=64)
    mreplyto = models.CharField(max_length=64)
    mid = models.CharField(max_length=254)
    mbcc = models.CharField(max_length=64)
    mcc = models.CharField(max_length=54)
    mbody = models.TextField() # This field type is a guess.
    mdate = models.DateTimeField()
    mstatus = models.TextField() # This field type is a guess.
    msrc = models.CharField(max_length=80)
    mgrp = models.TextField() # This field type is a guess.
    outtim = models.DateTimeField()
    outsts = models.TextField() # This field type is a guess.
    outtxt = models.CharField(max_length=128)
    outsrc = models.CharField(max_length=20)
    outkey = models.IntegerField()
    outtpl = models.CharField(max_length=32)
    outxid = models.CharField(max_length=254)
    outtpd = models.DateTimeField()
    _stpins = models.DateTimeField()
    _usrins = models.TextField() # This field type is a guess.
    _stpupd = models.DateTimeField()
    _usrupd = models.TextField() # This field type is a guess.
    _numver = models.IntegerField()
    _nxtrec = models.IntegerField()
    _grpusr = models.TextField() # This field type is a guess.
    _lvlsec = models.IntegerField()
    class Meta:
        db_table = 'lrr_dsd_out'

class DsdLao(models.Model):
    dsdlao = models.IntegerField(primary_key=True)
    hishis = models.ForeignKey(History, db_column='hishis')
    laotxt = models.CharField(max_length=255)
    laosrc = models.CharField(max_length=20)
    laokey = models.IntegerField()
    laoprg = models.CharField(max_length=20)
    _stpins = models.DateTimeField()
    _usrins = models.TextField() # This field type is a guess.
    _stpupd = models.DateTimeField()
    _usrupd = models.TextField() # This field type is a guess.
    _numver = models.IntegerField()
    _nxtrec = models.IntegerField()
    _grpusr = models.TextField() # This field type is a guess.
    _lvlsec = models.IntegerField()
    class Meta:
        db_table = 'dsd_lao'

class LrrDsdLao(models.Model):
    dsdlao = models.IntegerField(primary_key=True)
    hishis = models.ForeignKey(LrrHistory, db_column='hishis')
    laotxt = models.CharField(max_length=255)
    laosrc = models.CharField(max_length=20)
    laokey = models.IntegerField()
    laoprg = models.CharField(max_length=20)
    _stpins = models.DateTimeField()
    _usrins = models.TextField() # This field type is a guess.
    _stpupd = models.DateTimeField()
    _usrupd = models.TextField() # This field type is a guess.
    _numver = models.IntegerField()
    _nxtrec = models.IntegerField()
    _grpusr = models.TextField() # This field type is a guess.
    _lvlsec = models.IntegerField()
    class Meta:
        db_table = 'dsd_lao'

class DsdFld(models.Model):
    dsdfld = models.IntegerField(primary_key=True)
    fldidf = models.TextField() # This field type is a guess.
    fldtit = models.TextField() # This field type is a guess.
    flddes = models.TextField() # This field type is a guess.
    fldtyp = models.TextField() # This field type is a guess.
    fldzdr = models.TextField() # This field type is a guess.
    fldlen = models.SmallIntegerField()
    fldxmt = models.TextField() # This field type is a guess.
    fldxmp = models.TextField() # This field type is a guess.
    fldxmd = models.TextField() # This field type is a guess.
    fldxml = models.CharField(max_length=254)
    fldxms = models.CharField(max_length=254)
    class Meta:
        db_table = 'dsd_fld'

class LrrDsdFld(models.Model):
    dsdfld = models.IntegerField(primary_key=True)
    fldidf = models.TextField() # This field type is a guess.
    fldtit = models.TextField() # This field type is a guess.
    flddes = models.TextField() # This field type is a guess.
    fldtyp = models.TextField() # This field type is a guess.
    fldzdr = models.TextField() # This field type is a guess.
    fldlen = models.SmallIntegerField()
    fldxmt = models.TextField() # This field type is a guess.
    fldxmp = models.TextField() # This field type is a guess.
    fldxmd = models.TextField() # This field type is a guess.
    fldxml = models.CharField(max_length=254)
    fldxms = models.CharField(max_length=254)
    class Meta:
        db_table = 'lrr_dsd_fld'

class DsdFrm(models.Model):
    dsdfrm = models.IntegerField(primary_key=True)
    frmidf = models.TextField() # This field type is a guess.
    frmtit = models.TextField() # This field type is a guess.
    frmdes = models.TextField() # This field type is a guess.
    frmtyp = models.TextField() # This field type is a guess.
    frmxmo = models.TextField() # This field type is a guess.
    frmxmt = models.TextField() # This field type is a guess.
    frmxma = models.TextField() # This field type is a guess.
    frmver = models.TextField() # This field type is a guess.
    frmche = models.CharField(max_length=128)
    frmchm = models.CharField(max_length=128)
    frmema = models.TextField() # This field type is a guess.
    frmfce = models.CharField(max_length=128)
    frmact = models.TextField() # This field type is a guess.
    class Meta:
        db_table = 'dsd_frm'

class LrrDsdFrm(models.Model):
    dsdfrm = models.IntegerField(primary_key=True)
    frmidf = models.TextField() # This field type is a guess.
    frmtit = models.TextField() # This field type is a guess.
    frmdes = models.TextField() # This field type is a guess.
    frmtyp = models.TextField() # This field type is a guess.
    frmxmo = models.TextField() # This field type is a guess.
    frmxmt = models.TextField() # This field type is a guess.
    frmxma = models.TextField() # This field type is a guess.
    frmver = models.TextField() # This field type is a guess.
    frmche = models.CharField(max_length=128)
    frmchm = models.CharField(max_length=128)
    frmema = models.TextField() # This field type is a guess.
    frmfce = models.CharField(max_length=128)
    frmact = models.TextField() # This field type is a guess.
    class Meta:
        db_table = 'lrr_dsd_frm'

class DsdFxf(models.Model):
    dsdfxf = models.IntegerField(primary_key=True)
    dsdfrm = models.ForeignKey(DsdFrm, db_column='dsdfrm')
    dsdfld = models.ForeignKey(DsdFld, db_column='dsdfld')
    fxford = models.SmallIntegerField()
    fxfnul = models.TextField() # This field type is a guess.
    fxfche = models.CharField(max_length=254)
    fxfchm = models.CharField(max_length=254)
    fxffrm = models.TextField() # This field type is a guess.
    fxfval = models.TextField() # This field type is a guess.
    fxfxml = models.TextField() # This field type is a guess.
    fxfxmf = models.CharField(max_length=254)
    fxfdat = models.CharField(max_length=64)
    class Meta:
        db_table = 'dsd_fxf'

class LrrDsdFxf(models.Model):
    dsdfxf = models.IntegerField(primary_key=True)
    dsdfrm = models.ForeignKey(LrrDsdFrm, db_column='dsdfrm')
    dsdfld = models.ForeignKey(LrrDsdFld, db_column='dsdfld')
    fxford = models.SmallIntegerField()
    fxfnul = models.TextField() # This field type is a guess.
    fxfche = models.CharField(max_length=254)
    fxfchm = models.CharField(max_length=254)
    fxffrm = models.TextField() # This field type is a guess.
    fxfval = models.TextField() # This field type is a guess.
    fxfxml = models.TextField() # This field type is a guess.
    fxfxmf = models.CharField(max_length=254)
    fxfdat = models.CharField(max_length=64)
    class Meta:
        db_table = 'lrr_dsd_fxf'

class DsdIso(models.Model):
    dsdiso = models.IntegerField(primary_key=True)
    isodzp = models.DateTimeField()
    isodnl = models.DateTimeField()
    isosts = models.TextField() # This field type is a guess.
    isomd5 = models.CharField(max_length=35)
    isodat = models.TextField() # This field type is a guess.
    _stpins = models.DateTimeField()
    _usrins = models.TextField() # This field type is a guess.
    _stpupd = models.DateTimeField()
    _usrupd = models.TextField() # This field type is a guess.
    _numver = models.IntegerField()
    _nxtrec = models.IntegerField()
    _grpusr = models.TextField() # This field type is a guess.
    _lvlsec = models.IntegerField()
    class Meta:
        db_table = 'dsd_iso'

class DsdIsi(models.Model):
    dsdisi = models.IntegerField(primary_key=True)
    dsdiso = models.ForeignKey(DsdIso, db_column='dsdiso')
    dsdkon = models.ForeignKey(DsdContact, db_column='dsdkon')
    dsdpfo = models.ForeignKey(DsdSubject, db_column='dsdpfo')
    isidor = models.DateTimeField()
    isidzp = models.DateTimeField()
    isitim = models.DateTimeField()
    isityp = models.TextField() # This field type is a guess.
    isiema = models.CharField(max_length=128)
    isiclt = models.CharField(max_length=254)
    reqidf = models.TextField() # This field type is a guess.
    isimd5 = models.CharField(max_length=35)
    isidat = models.TextField() # This field type is a guess.
    _stpins = models.DateTimeField()
    _usrins = models.TextField() # This field type is a guess.
    _stpupd = models.DateTimeField()
    _usrupd = models.TextField() # This field type is a guess.
    _numver = models.IntegerField()
    _nxtrec = models.IntegerField()
    _grpusr = models.TextField() # This field type is a guess.
    _lvlsec = models.IntegerField()
    class Meta:
        db_table = 'dsd_isi'

class DsdDph(models.Model):
    dsddph = models.IntegerField(primary_key=True)
    dsdpfo = models.ForeignKey(DsdSubject, db_column='dsdpfo')
    dphdic = models.CharField(max_length=32)
    dphtyp = models.TextField() # This field type is a guess.
    dphdck = models.DateTimeField()
    dphsts = models.SmallIntegerField()
    dphnam = models.CharField(max_length=254)
    dphadr = models.CharField(max_length=254)
    _stpins = models.DateTimeField()
    _usrins = models.TextField() # This field type is a guess.
    _stpupd = models.DateTimeField()
    _usrupd = models.TextField() # This field type is a guess.
    _numver = models.IntegerField()
    _nxtrec = models.IntegerField()
    _grpusr = models.TextField() # This field type is a guess.
    _lvlsec = models.IntegerField()
    class Meta:
        db_table = 'dsd_dph'

class LrrDsdDph(models.Model):
    dsddph = models.IntegerField(primary_key=True)
    dsdpfo = models.ForeignKey(LrrDsdSubject, db_column='dsdpfo')
    dphdic = models.CharField(max_length=32)
    dphtyp = models.TextField() # This field type is a guess.
    dphdck = models.DateTimeField()
    dphsts = models.SmallIntegerField()
    dphnam = models.CharField(max_length=254)
    dphadr = models.CharField(max_length=254)
    _stpins = models.DateTimeField()
    _usrins = models.TextField() # This field type is a guess.
    _stpupd = models.DateTimeField()
    _usrupd = models.TextField() # This field type is a guess.
    _numver = models.IntegerField()
    _nxtrec = models.IntegerField()
    _grpusr = models.TextField() # This field type is a guess.
    _lvlsec = models.IntegerField()
    class Meta:
        db_table = 'lrr_dsd_dph'

class DsdOna(models.Model):
    dsdona = models.IntegerField(primary_key=True)
    dsdpfo = models.ForeignKey(DsdSubject, db_column='dsdpfo')
    onacol = models.TextField() # This field type is a guess.
    onatyp = models.TextField() # This field type is a guess.
    onanaz = models.CharField(max_length=254)
    onadod = models.DateField()
    onaddo = models.DateField()
    _stpins = models.DateTimeField()
    _usrins = models.TextField() # This field type is a guess.
    _stpupd = models.DateTimeField()
    _usrupd = models.TextField() # This field type is a guess.
    _numver = models.IntegerField()
    _nxtrec = models.IntegerField()
    _grpusr = models.TextField() # This field type is a guess.
    _lvlsec = models.IntegerField()
    class Meta:
        db_table = 'dsd_ona'

class DsdSou(models.Model):
    dsdsou = models.IntegerField(primary_key=True)
    dsddom = models.ForeignKey(DsdDomain, db_column='dsddom')
    dsdpra = models.ForeignKey(DsdPra, db_column='dsdpra')
    sourid = models.CharField(max_length=40)
    soujme = models.CharField(max_length=64)
    soupri = models.CharField(max_length=128)
    soutim = models.DateField()
    soudod = models.DateTimeField()
    souddo = models.DateTimeField()
    _stpins = models.DateTimeField()
    _usrins = models.TextField() # This field type is a guess.
    _stpupd = models.DateTimeField()
    _usrupd = models.TextField() # This field type is a guess.
    _numver = models.IntegerField()
    _nxtrec = models.IntegerField()
    _grpusr = models.TextField() # This field type is a guess.
    _lvlsec = models.IntegerField()
    class Meta:
        db_table = 'dsd_sou'

class LrrDsdSou(models.Model):
    dsdsou = models.IntegerField(primary_key=True)
    dsddom = models.ForeignKey(LrrDsdDomain, db_column='dsddom')
    dsdpra = models.ForeignKey(LrrDsdPra, db_column='dsdpra')
    sourid = models.CharField(max_length=40)
    soujme = models.CharField(max_length=64)
    soupri = models.CharField(max_length=128)
    soutim = models.DateField()
    soudod = models.DateTimeField()
    souddo = models.DateTimeField()
    _stpins = models.DateTimeField()
    _usrins = models.TextField() # This field type is a guess.
    _stpupd = models.DateTimeField()
    _usrupd = models.TextField() # This field type is a guess.
    _numver = models.IntegerField()
    _nxtrec = models.IntegerField()
    _grpusr = models.TextField() # This field type is a guess.
    _lvlsec = models.IntegerField()
    class Meta:
        db_table = 'lrr_dsd_sou'

class DsdReqOut(models.Model):
    id = models.IntegerField(primary_key=True)
    dsdout = models.IntegerField()
    dsdtyp = models.TextField()
    dsdreq = models.IntegerField()
    mto = models.CharField(max_length=100)
    mfrom = models.CharField(max_length=100)
    mfromadr = models.CharField(max_length=100)
    msubject = models.CharField(max_length=100)
    mreplyto = models.CharField(max_length=100)
    mid = models.CharField(max_length=100)
    mbcc = models.CharField(max_length=100)
    mcc = models.CharField(max_length=100)
    mbody = models.TextField()
    mdate = models.DateTimeField()
    mstatus = models.TextField() # This field type is a guess.
    msrc = models.CharField(max_length=100)
    mgrp = models.TextField() # This field type is a guess.
    outtim = models.DateTimeField()
    outsts = models.TextField() # This field type is a guess.
    outtxt = models.CharField(max_length=100)
    outsrc = models.CharField(max_length=100)
    outkey = models.IntegerField()
    outtpl = models.CharField(max_length=100)
    outxid = models.CharField(max_length=100)
    outtpd = models.DateTimeField()
    _stpins = models.DateTimeField()
    _usrins = models.TextField() # This field type is a guess.
    _stpupd = models.DateTimeField()
    _usrupd = models.TextField() # This field type is a guess.
    _numver = models.IntegerField()
    _nxtrec = models.IntegerField()
    _grpusr = models.TextField() # This field type is a guess.
    _lvlsec = models.IntegerField()
    class Meta:
        db_table = 'dsd_req_out'

class LrrReqOut(models.Model):
    dsdout = models.IntegerField(primary_key=True)
    dsdtyp = models.TextField()
    dsdreq = models.IntegerField()
    mto = models.CharField(max_length=100)
    mfrom = models.CharField(max_length=100)
    mfromadr = models.CharField(max_length=100)
    msubject = models.CharField(max_length=100)
    mreplyto = models.CharField(max_length=100)
    mid = models.CharField(max_length=100)
    mbcc = models.CharField(max_length=100)
    mcc = models.CharField(max_length=100)
    mbody = models.TextField()
    mdate = models.DateTimeField()
    mstatus = models.TextField() # This field type is a guess.
    msrc = models.CharField(max_length=100)
    mgrp = models.TextField() # This field type is a guess.
    outtim = models.DateTimeField()
    outsts = models.TextField() # This field type is a guess.
    outtxt = models.CharField(max_length=100)
    outsrc = models.CharField(max_length=100)
    outkey = models.IntegerField()
    outtpl = models.CharField(max_length=100)
    outxid = models.CharField(max_length=100)
    outtpd = models.DateTimeField()
    _stpins = models.DateTimeField()
    _usrins = models.TextField() # This field type is a guess.
    _stpupd = models.DateTimeField()
    _usrupd = models.TextField() # This field type is a guess.
    _numver = models.IntegerField()
    _nxtrec = models.IntegerField()
    _grpusr = models.TextField() # This field type is a guess.
    _lvlsec = models.IntegerField()
    class Meta:
        db_table = 'lrr_req_out'

class LrrRsdPod(models.Model):
    rsdpod = models.IntegerField(primary_key=True)
    poddor = models.DateTimeField()
    poddzp = models.DateTimeField()
    podtyp = models.TextField(choices=requestTypeList) # This field type is a guess.
    podidf = models.TextField() # This field type is a guess.
    podmfr = models.CharField(max_length=254)
    podmid = models.CharField(max_length=254)
    poddat = models.TextField()
    podsts = models.TextField(choices=requestStatusList) # This field type is a guess.
    reqsub = models.CharField(max_length=254)
    reqtob = models.CharField(max_length=20)
    reqkey = models.IntegerField()
    class Meta:
        db_table = 'lrr_rsd_pod'

class LrrRsdPrd(models.Model):
    rsdprd = models.IntegerField(primary_key=True)
    rsdpod = models.ForeignKey(LrrRsdPod, db_column='rsdpod')
    prdnam = models.CharField(max_length=32)
    prdval = models.CharField(max_length=254)
    class Meta:
        db_table = 'sumo_rsd_prd'



class PragPlatby(models.Model):
    id              = models.IntegerField(primary_key=True)
    efekt           = models.TextField(verbose_name='Efekt', choices=pragEfekt)
    rok             = models.IntegerField()
    kod_dokladu     = models.TextField(verbose_name='Kód dokladu', choices=pragKodDokladu)
    cislo_dokladu   = models.IntegerField()
    cislo_radku     = models.IntegerField()
    datum           = models.DateField()
    strana          = models.CharField(max_length=1)
    castka          = models.DecimalField(max_digits=13, decimal_places=2)
    castka_zbyva    = models.DecimalField(max_digits=13, decimal_places=2)
    bank_ucet       = models.CharField(max_length=50)
    kod_banky       = models.CharField(max_length=4)
    ks              = models.CharField(max_length=50)
    vs              = models.CharField(max_length=50)
    ss              = models.CharField(max_length=50)
    vlozeno         = models.DateTimeField()
    class Meta:
        db_table = 'prag_platby'
    
class PragBanky(models.Model):
    id              = models.IntegerField(primary_key=True)
    efekt           = models.TextField(verbose_name='Efekt', choices=pragEfekt)
    rok             = models.IntegerField()
    kod_dokladu     = models.TextField(verbose_name='Kód dokladu', choices=pragKodDokladu)
    cislo_dokladu   = models.IntegerField()
    cislo_radku     = models.IntegerField()
    datum           = models.DateField()
    strana          = models.CharField(max_length=1)
    castka          = models.DecimalField(max_digits=13, decimal_places=2)
    castka_zbyva    = models.DecimalField(max_digits=13, decimal_places=2)
    bank_ucet       = models.CharField(max_length=50)
    kod_banky       = models.CharField(max_length=4)
    ks              = models.CharField(max_length=50)
    vs              = models.CharField(max_length=50)
    ss              = models.CharField(max_length=50)
    vlozeno         = models.DateTimeField()
    class Meta:
        db_table = 'prag_banky'


class PragVnitrniDoklady(models.Model):
    id              = models.IntegerField(primary_key=True)
    efekt           = models.TextField(verbose_name='Efekt', choices=pragEfekt)
    rok             = models.IntegerField()
    kod_dokladu     = models.TextField(verbose_name='Kód dokladu', choices=pragKodDokladu)
    cislo_dokladu   = models.IntegerField()
    cislo_radku     = models.IntegerField()
    datum           = models.DateField()
    strana          = models.CharField(max_length=1)
    castka          = models.DecimalField(max_digits=13, decimal_places=2)
    castka_zbyva    = models.DecimalField(max_digits=13, decimal_places=2)
    vs              = models.CharField(max_length=50)
    vlozeno         = models.DateTimeField()
    class Meta:
        db_table = 'prag_vnitrni_doklady'

class PragFaktury(models.Model):
    id              = models.IntegerField(primary_key=True)
    efekt           = models.TextField(verbose_name='Efekt', choices=pragEfekt)
    rok             = models.IntegerField()
    kod_dokladu     = models.TextField(verbose_name='Kód dokladu', choices=pragKodDokladu)
    cislo_dokladu   = models.IntegerField()
    cislo_radku     = models.IntegerField()
    datum           = models.DateField()
    strana          = models.CharField(max_length=1)
    castka          = models.DecimalField(max_digits=13, decimal_places=2)
    castka_zbyva    = models.DecimalField(max_digits=13, decimal_places=2)
    vs              = models.CharField(max_length=50)
    vlozeno         = models.DateTimeField()
    class Meta:
        db_table = 'prag_faktury'
    

class PragVazby(models.Model):
    id              = models.IntegerField(primary_key=True)
    klic1_id        = models.IntegerField()
    klic1_typ       = models.TextField(verbose_name='1. Typ pohybu', choices=pragVazby)
    klic2_id        = models.IntegerField()
    klic2_typ       = models.TextField(verbose_name='2. Typ pohybu', choices=pragVazby)
    castka          = models.DecimalField(max_digits=13, decimal_places=2)
    vlozeno         = models.DateTimeField()
    class Meta:
        db_table = 'prag_vazby'
