# -*- coding: utf-8 -*-
#--------------------------------------
# django 0.96     |   django 0.97
#--------------------------------------
# form.clean_data |   form.cleaned_data


from django.template import Context, loader
from django.http import HttpResponse, HttpResponseRedirect, Http404
from django import forms
#from django.core.paginator import ObjectPaginator, InvalidPage
from django.core.paginator import Paginator, InvalidPage, EmptyPage

from codebook import *
from browser.models import DsdDomain, DsdContact, DsdAddress, DsdSubject, \
                           DsdDomain_x_Subject, DsdDns, DsdRequest, DsdOut, DsdAns, History, \
                           DsdReqOut, DsdTet, DsdQit, \
                           LrrDsdDomain, LrrDsdContact, LrrDsdAddress, LrrDsdSubject, \
                           LrrDsdDomain_x_Subject, LrrDsdDns, LrrDsdRequest, LrrDsdOut, LrrHistory, \
                           LrrReqOut, LrrRsdPod, \
                           PragPlatby, PragBanky, PragVnitrniDoklady, PragFaktury, PragVazby

import time
import datetime
import textwrap
from pprint import pprint as pp

def mrproper(dict):
    # function for removing keys with no values from dict, returns new dict
    # usage: cleaning out empty values passed to forms
    new = {}
    [ new.__setitem__(key, dict[key]) for key in dict if dict[key] ]
    return new

def pager(paginator, page):
    # generates list of pages from min+1 to max-1, outer limits are fixed in template
    # usage: page links in pager macro
    adjacent = 10
    pages = [n for n in range(page - adjacent, page + adjacent + 1) if n>1 and n<paginator.num_pages]
    return pages

def index(request):
    t = loader.get_template('index.html')
    return HttpResponse(t.render(Context()))

class DomainForm(forms.Form):
    domjme__iexact = forms.CharField(required=False, label='Doménové jméno', widget=forms.TextInput(attrs={'size':'45'}))
    domtch__exact = forms.DateField(required=False, input_formats=['%d.%m.%Y','%d.%m.%y',], label='Technická kontrola')
    domdod__gte = forms.DateField(required=False, input_formats=['%d.%m.%Y','%d.%m.%y','%m.%y'], label='Datum registrace od')
    domdod__lte = forms.DateField(required=False, input_formats=['%d.%m.%Y','%d.%m.%y','%m.%y'], label='Datum registrace do')
    domddo__gte = forms.DateField(required=False, input_formats=['%d.%m.%Y','%d.%m.%y','%m.%y'], label='Ukonč. registrace od')
    domddo__lte = forms.DateField(required=False, input_formats=['%d.%m.%Y','%d.%m.%y','%m.%y'], label='Ukonč. registrace do')
    domkst__exact = forms.ChoiceField(required=False, choices=[['', '']]+domainStatusList, label='Stav')
    domgen__exact = forms.ChoiceField(required=False, choices=[['', '']]+domainInZone, label='Generace do zóny')
    domdes__icontains = forms.CharField(required=False, label='Popis', max_length=128)
    dommno__icontains = forms.CharField(required=False, label='Email pro notify', max_length=254, widget=forms.TextInput(attrs={'size':'40'}))
#    domreg__exact = forms.ChoiceField(required=False, choices=[['', '']]+domainInZone, label='Generace do zóny')

def domain_form(request):
    t = loader.get_template('domain.form.html')
    form = DomainForm(request.POST)
    if request.method == "POST" and form.is_valid():
        filters = mrproper(form.cleaned_data) # form.clean_data
        request.session['domain'] = filters
        return HttpResponseRedirect('/domain/result/?page=1')
    else:
        try:
            del request.session['domain']
        except KeyError:
            pass
        c = Context({
            'form': form
        })
        return HttpResponse(t.render(c))

def domain_result(request):
    try:
        page = int(request.GET.get('page', 1))
    except ValueError:
        page = 1
    t = loader.get_template('domain.result.html')
    filters = request.session['domain']
    query_set = DsdDomain.objects.filter(**filters).order_by('domjme')#.order_by('-domdod')
    paginator = Paginator(query_set, 100)
    page = int(page)
    try:
        result = paginator.page(page).object_list
    except InvalidPage:
        raise Http404
    if paginator.num_pages == 1 and paginator.count == 1:
        return HttpResponseRedirect('/domain/%s/history/' % (query_set[0].domjme))
    for d in result:
        try:
            s = d.dsddomain_x_subject_set.get(dxsddo__isnull=True, dxstyp='Z').dsdpfo
        except:
            s = ''
        try:
            r = d.dsddomain_x_subject_set.get(dxsddo__isnull=True, dxstyp='R').dsdpfo
        except:
            r = ''
        d.subject = s
        d.registrar = r
    pager_macro = loader.get_template('macro.pager.html').render(Context({'paginator':paginator, 'page_range': pager(paginator, page), 'page': page}))
    c = Context({
        'domains': result,
        'pager_macro': pager_macro,
        'paginator': paginator,
    })
    return HttpResponse(t.render(c))

def domain_list(request, domjme=None, history=None):
    result = DsdDomain.objects.filter(domjme=domjme).order_by('-domdod')
    if len(result) == 1:
        h = ''
        if history:
            h = "%s/" % (history,)
        return HttpResponseRedirect('/domain/%s/%s/%s' % (result[0].domjme, result[0].dsddom, h))
    else:
        r = []
        for d in result:
            s = d.dsddomain_x_subject_set.get(dxsddo__isnull=True, dxstyp='Z').dsdpfo
            r.append({'domain': d,
                      'subject': s,
                    })
        current = None
        if r and not r[0]['domain'].domddo:
            current = r.pop(0)
        t = loader.get_template('domain.list.html')
        c = Context({
            'domjme': domjme,
            'current': current,
                'domains': r,
            'history': history,
        })
        return HttpResponse(t.render(c))

def domain_detail(request, domjme=None, dsddom=None, history=None):
    try:
        domain = DsdDomain.objects.get(domjme=domjme, dsddom=dsddom)
    except DsdDomain.DoesNotExist:
        return HttpResponse("No such domain found")
    hist = {}
    dns = { 'primary': domain.dns().filter(dnsddo__isnull=True, dnstyp='P').order_by('dnsdns'),
            'secondary': domain.dns().filter(dnsddo__isnull=True, dnstyp='S').order_by('dnsdns') }
    try:
        owner = domain.subjects().get(dxsddo__isnull=True, dxstyp='Z')
    except:
        owner = None
    try:
        tech = domain.subjects().get(dxsddo__isnull=True, dxstyp='T')
    except:
        tech = None
    try:
        reg = domain.subjects().get(dxsddo__isnull=True, dxstyp='R')
    except:
        reg = None
    sou = domain.rules().order_by('-soudod')
    dsd_requests = DsdRequest.objects.filter(reqtob='dsd_dom', reqkey=domain.dsddom).order_by('-reqdor')
    lrr_requests = LrrDsdRequest.objects.filter(reqtob='dsd_dom', reqkey=domain.dsddom).order_by('-reqdor')
    rsd_requests = LrrRsdPod.objects.filter(reqtob='dsd_dom', reqkey=domain.dsddom).order_by('-poddor')
    if history:
        hist['des'] = domain.history().filter(histab='dsd_dom', hiscol='domdes').order_by('-hisstp') or []
        hist['mno'] = domain.history().filter(histab='dsd_dom', hiscol='dommno').order_by('-hisstp') or []
        dns_hist = domain.dns().filter(dnsddo__isnull=False).order_by('-dnsddo', 'dnstyp')
        hist['dns']   = zip(dns_hist[::2], dns_hist[1:len(dns_hist):2]) or []
        hist['owner'] = domain.subjects().filter(dxsddo__isnull=False, dxstyp='Z').order_by('-dxsdod') or []
        hist['tech']  = domain.subjects().filter(dxsddo__isnull=False, dxstyp='T').order_by('-dxsdod') or []
        hist['reg']   = domain.subjects().filter(dxsddo__isnull=False, dxstyp='R').order_by('-dxsdod') or []
    dsd_req_macro = loader.get_template('macro.dsd_requests.list.html').render(Context({'dsd_requests':dsd_requests}))
    lrr_req_macro = loader.get_template('macro.lrr_requests.list.html').render(Context({'lrr_requests':lrr_requests}))
    rsd_req_macro = loader.get_template('macro.rsd_requests.list.html').render(Context({'rsd_requests':rsd_requests}))
    t = loader.get_template('domain.detail.html')
    c = Context({
        'domain': domain,
        'dns': dns,
        'owner': owner,
        'tech': tech,
        'reg': reg,
        'sou': sou,
        'dsd_req_macro': dsd_req_macro,
        'lrr_req_macro': lrr_req_macro,
        'rsd_req_macro': rsd_req_macro,
        'history': hist,
    })
    return HttpResponse(t.render(c))

class SubjectForm(forms.Form):
    pfotyp__exact = forms.ChoiceField(required=False, choices=[['', '']]+subjectType, label='Právní forma')
    pfosts__icontains = forms.CharField(required=False, label='Status')
    pfonaz__icontains = forms.CharField(required=False, label='Obchodní jméno', widget=forms.TextInput(attrs={'size':'45'}))
    pfodnr__exact = forms.DateField(required=False, input_formats=['%d.%m.%Y'], label='Datum narození')
    pfojme__icontains = forms.CharField(required=False, label='Jméno')
    pfopri__icontains = forms.CharField(required=False, label='Příjmení', widget=forms.TextInput(attrs={'size':'35'}))
    pfoico__iexact = forms.CharField(required=False, label='IČO')
    pfodic__iexact = forms.CharField(required=False, label='DIČ')
    pfoema__iexact = forms.CharField(required=False, label='Email subjektu', widget=forms.TextInput(attrs={'size':'45'}))
    pfotno__exact = forms.ChoiceField(required=False, choices=[['', '']]+notifyType, label='Typ notifikace')
    pfomno__iexact = forms.CharField(required=False, label='Email adresa pro Notify', widget=forms.TextInput(attrs={'size':'45'}))
    pfotat__iexact = forms.ChoiceField(required=False, choices=[['', '']]+subjectAuthList, label='Typ autorizace')
    pforid__iexact = forms.CharField(required=False, label='Identifikátor subjektu', widget=forms.TextInput(attrs={'size':'25'}))
    pfodod__gte = forms.DateField(required=False, input_formats=['%d.%m.%Y','%d.%m.%y','%m.%y'], label='Datum registrace od')
    pfodod__lte = forms.DateField(required=False, input_formats=['%d.%m.%Y','%d.%m.%y','%m.%y'], label='Datum registrace do')
    pfoddo__gte = forms.DateField(required=False, input_formats=['%d.%m.%Y','%d.%m.%y','%m.%y'], label='Ukonč. registrace od')
    pfoddo__lte = forms.DateField(required=False, input_formats=['%d.%m.%Y','%d.%m.%y','%m.%y'], label='Ukonč. registrace do')

def subject_form(request):
    t = loader.get_template('subject.form.html')
    form = SubjectForm(request.POST)
    if request.method == "POST" and form.is_valid():
        filters = mrproper(form.cleaned_data)
        request.session['subject'] = filters
        return HttpResponseRedirect('/subject/result/?page=1')
    else:
        try:
            del request.session['subject']
        except KeyError:
            pass
        c = Context({
            'form': form
        })
        return HttpResponse(t.render(c))

def subject_result(request):
    try:
        page = int(request.GET.get('page', 1))
    except ValueError:
        page = 1
    t = loader.get_template('subject.result.html')
    filters = request.session['subject']
    query_set = DsdSubject.objects.filter(**filters).order_by('pforid')
    paginator = Paginator(query_set, 100)
    page = int(page)
    try:
        result = paginator.page(page).object_list
    except InvalidPage:
        raise Http404
    if paginator.num_pages == 1 and paginator.count == 1:
        return HttpResponseRedirect('/subject/%s/history/' % (query_set[0].pforid))
    pager_macro = loader.get_template('macro.pager.html').render(Context({'paginator':paginator, 'page_range': pager(paginator, page), 'page': page}))
    c = Context({
        'subjects': result,
        'pager_macro': pager_macro,
        'paginator': paginator,
    })
    return HttpResponse(t.render(c))

def subject_detail(request, pforid=None, history=None):
    hist = {}
    requests = None
    try:
        subject = DsdSubject.objects.get(pforid=pforid)
    except DsdSubject.DoesNotExist:
        subject = None
        address = None
        admin = None
        tech = None
        fakt = None
    if subject:
        address = subject.dsdaddress_set.filter(adrddo__isnull=True).order_by('-adrdod')
        admin = subject.contacts().filter(kxstyp='A', kxspdo__isnull=True).order_by('-kxspod')
        tech = subject.contacts().filter(kxstyp='T', kxspdo__isnull=True).order_by('-kxspod')
        fakt = subject.contacts().filter(kxstyp='F', kxspdo__isnull=True).order_by('-kxspod')
        dsd_requests = DsdRequest.objects.filter(reqtob='dsd_pfo', reqkey=subject.dsdpfo).order_by('-reqdor')
        lrr_requests = LrrDsdRequest.objects.filter(reqtob='dsd_pfo', reqkey=subject.dsdpfo).order_by('-reqdor')
        rsd_requests = LrrRsdPod.objects.filter(reqtob='dsd_pfo', reqkey=subject.dsdpfo).order_by('-poddor')
        if history:
            hist['naz'] = subject.history().filter(histab='dsd_pfo', hiscol='pfonaz').order_by('-hisstp') or []
            hist['ico'] = subject.history().filter(histab='dsd_pfo', hiscol='pfoico').order_by('-hisstp') or []
            hist['dic'] = subject.history().filter(histab='dsd_pfo', hiscol='pfodic').order_by('-hisstp') or []
            hist['ema'] = subject.history().filter(histab='dsd_pfo', hiscol='pfoema').order_by('-hisstp') or []
            hist['tno'] = subject.history().filter(histab='dsd_pfo', hiscol='pfotno').order_by('-hisstp') or []
            hist['mno'] = subject.history().filter(histab='dsd_pfo', hiscol='pfomno').order_by('-hisstp') or []
            address = subject.dsdaddress_set.order_by('-adrdod')
            admin = subject.contacts().filter(kxstyp='A').order_by('-kxspod')
            tech = subject.contacts().filter(kxstyp='T').order_by('-kxspod')
            fakt = subject.contacts().filter(kxstyp='F').order_by('-kxspod')
    dsd_req_macro = loader.get_template('macro.dsd_requests.list.html').render(Context({'dsd_requests':dsd_requests}))
    lrr_req_macro = loader.get_template('macro.lrr_requests.list.html').render(Context({'lrr_requests':lrr_requests}))
    rsd_req_macro = loader.get_template('macro.rsd_requests.list.html').render(Context({'rsd_requests':rsd_requests}))
    t = loader.get_template('subject.detail.html')
    c = Context({
        'subject': subject,
        'pforid': pforid,
        'address': address,
        'admin': admin,
        'tech': tech,
        'fakt': fakt,
        'dsd_req_macro': dsd_req_macro,
        'lrr_req_macro': lrr_req_macro,
        'rsd_req_macro': rsd_req_macro,
        'history': hist,
    })
    return HttpResponse(t.render(c))

def contact_form(request):
    t = loader.get_template('contact.form.html')
    f = request.POST
    konrid = request.POST.get('konrid', None)
    history = request.POST.get('history', None)
    if konrid:
        h = ''
        if history:
            h = "%s/" % (history,)
        return HttpResponseRedirect('/contact/%s/%s' % (konrid, h))
    else:
        c = Context({})
        return HttpResponse(t.render(c))

def contact_detail(request, konrid=None, history=None):
    hist = {}
    requests = None
    try:
        contact = DsdContact.objects.get(konrid=konrid)
    except DsdContact.DoesNotExist:
        contact = None
        pgp = None
#        hist = None
    if contact:
        pgp = contact.dsdpgp_set.filter(pgpddo__isnull=True).order_by('-pgpdod')
        dsd_requests = DsdRequest.objects.filter(reqtob='dsd_kon', reqkey=contact.dsdkon).order_by('-reqdor')
        lrr_requests = LrrDsdRequest.objects.filter(reqtob='dsd_kon', reqkey=contact.dsdkon).order_by('-reqdor')
        rsd_requests = LrrRsdPod.objects.filter(reqtob='dsd_kon', reqkey=contact.dsdkon).order_by('-poddor')
#        hist = {}
        if history:
            hist['uli'] = contact.history().filter(histab='dsd_kon', hiscol='konuli').order_by('-hisstp')
            hist['mis'] = contact.history().filter(histab='dsd_kon', hiscol='konmis').order_by('-hisstp')
            hist['psc'] = contact.history().filter(histab='dsd_kon', hiscol='konpsc').order_by('-hisstp')
            hist['sta'] = contact.history().filter(histab='dsd_kon', hiscol='konsta').order_by('-hisstp')
            hist['tps'] = contact.history().filter(histab='dsd_kon', hiscol='kontps').order_by('-hisstp')
            hist['nps'] = contact.history().filter(histab='dsd_kon', hiscol='konnps').order_by('-hisstp')
            hist['emk'] = contact.history().filter(histab='dsd_kon', hiscol='konemk').order_by('-hisstp') or []
            hist['tel'] = contact.history().filter(histab='dsd_kon', hiscol='kontel').order_by('-hisstp') or []
            hist['fax'] = contact.history().filter(histab='dsd_kon', hiscol='konfax').order_by('-hisstp') or []
            hist['eno'] = contact.history().filter(histab='dsd_kon', hiscol='koneno').order_by('-hisstp') or []
            hist['tno'] = contact.history().filter(histab='dsd_kon', hiscol='kontno').order_by('-hisstp') or []
            pgp = contact.dsdpgp_set.order_by('-pgpdod')
        dsd_req_macro = loader.get_template('macro.dsd_requests.list.html').render(Context({'dsd_requests':dsd_requests}))
        lrr_req_macro = loader.get_template('macro.lrr_requests.list.html').render(Context({'lrr_requests':lrr_requests}))
        rsd_req_macro = loader.get_template('macro.rsd_requests.list.html').render(Context({'rsd_requests':rsd_requests}))
        t = loader.get_template('contact.detail.html')
        c = Context({
            'contact': contact,
            'konrid': konrid,
            'pgp': pgp,
            'dsd_req_macro': dsd_req_macro,
            'lrr_req_macro': lrr_req_macro,
            'rsd_req_macro': rsd_req_macro,
            'history': hist,
        })
        return HttpResponse(t.render(c))
    else:
        return HttpResponse('Kontakt "%s" neexistuje.' % konrid)

class RequestForm(forms.Form):
    reqidf__exact = forms.CharField(required=False, label='Ticket', widget=forms.TextInput(attrs={'size':'35'}))
    reqtyp__in = forms.ChoiceField(required=False, choices=[['', '']]+requestTypeList, label="Typ požadavku")
    reqrpl__icontains = forms.CharField(required=False, label='From', max_length=128)
    reqsub__icontains = forms.CharField(required=False, label='Subject', max_length=254, widget=forms.TextInput(attrs={'size':'40'}))
    reqdor__gte = forms.DateField(required=False, input_formats=['%d.%m.%Y','%d.%m.%y','%m.%y'], label='Doručeno od (včetně)')
    reqdor__lte = forms.DateField(required=False, input_formats=['%d.%m.%Y','%d.%m.%y','%m.%y'], label='Doručeno do (včetně)')
    reqdordate__exact = forms.DateField(required=False, label='Doručeno dne')
    dsdpfo__pforid__exact = forms.ChoiceField(required=False, choices=[['', '']]+registrarsList, label='Registrátor')
    reqsts__exact = forms.ChoiceField(required=False, choices=[['', '']]+requestStatusList, label='Status')
    reqdat__icontains = forms.CharField(required=False, label='Text', widget=forms.TextInput(attrs={'size':'45'}))

class RsdRequestForm(forms.Form):
    podidf__exact = forms.CharField(required=False, label='Ticket', widget=forms.TextInput(attrs={'size':'35'}))
    podtyp__in = forms.ChoiceField(required=False, choices=[['', '']]+requestTypeList, label="Typ požadavku")
    poddor__gte = forms.DateField(required=False, input_formats=['%d.%m.%Y','%d.%m.%y','%m.%y'], label='Doručeno od (včetně)')
    poddor__lte = forms.DateField(required=False, input_formats=['%d.%m.%Y','%d.%m.%y','%m.%y'], label='Doručeno do (včetně)')
    podsts__exact = forms.ChoiceField(required=False, choices=[['', '']]+requestStatusList, label='Status')
    poddat__icontains = forms.CharField(required=False, label='Text', widget=forms.TextInput(attrs={'size':'45'}))

def request_form(request, reqtype='dsd'):
    prefix = ''
    t = loader.get_template('request.form.html')
    frm = RequestForm
    if reqtype == 'lrr':
        prefix = 'lrr_'
    elif reqtype == 'rsd':
        prefix = 'rsd_'
        t = loader.get_template('request.form.rsd.html')
        frm = RsdRequestForm
    form = frm(request.POST)
    if request.method == "POST" and form.is_valid():
        filters = mrproper(form.cleaned_data)
        request.session['%srequest' % (prefix,)] = filters
        return HttpResponseRedirect('/%srequest/result/?page=1' % (prefix,))
    else:
        try:
            del request.session['%srequest' % (prefix,)]
        except KeyError:
            pass
        c = Context({
            'form': form
        })
        return HttpResponse(t.render(c))

def request_result(request, reqtype='dsd'):
    prefix = ''
    t = loader.get_template('request.result.html')
    if reqtype == 'dsd':
        Request = DsdRequest
    elif reqtype == 'lrr':
        prefix = 'lrr_'
        Request = LrrDsdRequest
    elif reqtype == 'rsd':
        prefix = 'rsd_'
        Request = LrrRsdPod
    try:
        page = int(request.GET.get('page', 1))
    except ValueError:
        page = 1
    filters = request.session['%srequest' % (prefix,)]
    query_set = Request.objects.filter(**filters).order_by('reqdor')
    paginator = Paginator(query_set, 100)
    page = int(page)
    try:
        result = paginator.page(page).object_list
    except InvalidPage:
        raise Http404
    if paginator.num_pages == 1 and paginator.count == 1:
        return HttpResponseRedirect('/%srequest/%s/' % (prefix, query_set[0].dsdreq))
    if reqtype == 'dsd':
        dsd_req_macro = loader.get_template('macro.dsd_requests.list.html').render(Context({'dsd_requests':result}))
    else: dsd_req_macro = None
    if reqtype == 'lrr':
        lrr_req_macro = loader.get_template('macro.lrr_requests.list.html').render(Context({'lrr_requests':result}))
    else: lrr_req_macro = None
    if reqtype == 'rsd':
        rsd_req_macro = loader.get_template('macro.rsd_requests.list.html').render(Context({'rsd_requests':result}))
    else: rsd_req_macro = None
    pager_macro = loader.get_template('macro.pager.html').render(Context({'paginator':paginator, 'page_range': pager(paginator, page), 'page': page}))
    c = Context({
        'dsd_req_macro': dsd_req_macro,
        'lrr_req_macro': lrr_req_macro,
        'rsd_req_macro': rsd_req_macro,
        'pager_macro': pager_macro,
        'paginator': paginator,
    })
    return HttpResponse(t.render(c))

def request_detail(request, dsdreq=None, history=None, reqtype='dsd'):
    template = 'request.detail.html'
    if reqtype == 'dsd':
        Request = DsdRequest
    elif reqtype == 'rsd':
        Request = LrrRsdPod
        template = 'rsd.detail.html'
    else:
        Request = LrrDsdRequest
    if reqtype == 'rsd':
        try:
            req = Request.objects.get(rsdpod=dsdreq)
        except Request.DoesNotExist:
            req = None
    else:
        try:
            req = Request.objects.get(dsdreq=dsdreq)
        except Request.DoesNotExist:
            req = None
    related = {}
    types = {'dsd_dom': DsdDomain, 'dsd_kon': DsdContact, 'dsd_pfo': DsdSubject}
    dirs = {'dsd_dom': 'domain', 'dsd_kon': 'contact', 'dsd_pfo': 'subject'}
    if req:
        rel = types.get(req.reqtob)
        if rel:
            try:
                obj = rel.objects.get(pk=req.reqkey)
            except rel.DoesNotExist:
                related = None
            else:
                related['type'] = dirs.get(req.reqtob)
                if related['type'] == 'domain':
                    related['value'] = "%s '%s' (id:%s)" % (obj._meta.object_name, obj.domjme, obj.dsddom)
                    related['link'] = "%s/%s" % (obj.domjme, obj.dsddom)
                if related['type'] == 'contact':
                    related['value'] = "%s '%s %s' (id:%s)" % (obj._meta.object_name, obj.konjme, obj.konpri, obj.konrid)
                    related['link'] = obj.konrid
                if related['type'] == 'subject':
                    related['value'] = "%s '%s' (id:%s)" % (obj._meta.object_name, obj.pfonaz, obj.pforid)
                    related['link'] = obj.pforid

    t = loader.get_template(template)
    c = Context({
        'request': req,
        'related': related,
        'reqtype': reqtype,
        'history': history,
    })
    return HttpResponse(t.render(c))

def lrr_request_detail(request, dsdreq=None, history=None):
    return request_detail(request, dsdreq=dsdreq, history=history, reqtype='lrr')

def rsd_request_detail(request, dsdreq=None, history=None):
    return request_detail(request, dsdreq=dsdreq, history=history, reqtype='rsd')

def out_list(request, outsrc=None, outkey=None, history=None, outtype='dsd'):
    outsrc = str(outsrc).lower()
    outs = []
    if outtype == 'dsd':
        Out = DsdOut
        ReqOut = DsdReqOut
    else:
        Out = LrrDsdOut
        ReqOut = LrrReqOut
    if outsrc in ['dsd_dom', 'dsd_pfo', 'dsd_kon']:
        try:
            outs = Out.objects.filter(outsrc=outsrc, outkey=outkey)
        except:
            pass
    elif outsrc == 'dsd_tet':
        try:
            outkeys = [t.dsdqit for t in DsdTet.objects.get(dsdtet=outkey).dsdqit_set.order_by('-tstdate')]
            outs = Out.objects.filter(outsrc='dsd_qit', outkey__in=outkeys)
        except:
            pass
    elif outsrc == 'dsd_req':
        try:
            outs = ReqOut.objects.filter(dsdreq=outkey)
        except:
            pass
    else:
        outs = []
    t = loader.get_template('out.list.html')
    c = Context({
        'outs': outs,
        'history': history,
    })
    return HttpResponse(t.render(c))

def lrr_out_list(request, outsrc=None, outkey=None, history=None):
    return out_list(request, outsrc=outsrc, outkey=outkey, history=history, outtype='lrr')

def out_detail(request, dsdout=None, history=None, outtype='dsd'):
    answer = None
    if outtype == 'dsd':
        Out = DsdOut
    else:
        Out = LrrDsdOut
    try:
        out = Out.objects.get(dsdout=dsdout)
    except Out.DoesNotExist:
        out = None
    if out:
        if outtype == 'lrr':
            anssnd = 'LRR'
        else:
            anssnd = 'C'
        try:
            answer = DsdAns.objects.get(ansoid=out.dsdout, anssnd=anssnd)
        except DsdAns.DoesNotExist:
            answer = None
        if not answer and outtype == 'dsd': # catch for bug if "ansoid and not anssnd"
            try:
                answer = DsdAns.objects.get(ansoid=out.dsdout)
            except DsdAns.DoesNotExist:
                answer = None # only now we really know if there is no DSD back-reference
    t = loader.get_template('out.detail.html')
    c = Context({
        'out': out,
        'outtype': outtype,
        'answer': answer,
        'history': history,
    })
    return HttpResponse(t.render(c))

def lrr_out_detail(request, dsdout=None, history=None):
    return out_detail(request, dsdout=dsdout, history=history, outtype='lrr')

class TechtestForm(forms.Form):
    dsddom__domjme__exact = forms.CharField(required=False, label='Doménové jméno', widget=forms.TextInput(attrs={'size':'35'}))
    tetnsg__icontains = forms.CharField(required=False, label="Parametry", widget=forms.TextInput(attrs={'size':'35'}))
    tetclr__icontains = forms.CharField(required=False, label='Ticket klienta', widget=forms.TextInput(attrs={'size':'35'}))
    tetpky__icontains = forms.CharField(required=False, label='Public Key', widget=forms.TextInput(attrs={'size':'40'}))
    regdate__gte = forms.DateField(required=False, input_formats=['%d.%m.%Y','%d.%m.%y','%m.%y'], label='Datum zařazení od (včetně)')
    regdate__lte = forms.DateField(required=False, input_formats=['%d.%m.%Y','%d.%m.%y','%m.%y'], label='Datum zařazení do (včetně)')
    expdate__gte = forms.DateField(required=False, input_formats=['%d.%m.%Y','%d.%m.%y','%m.%y'], label='Datum ukončení od (včetně)')
    expdate__lte = forms.DateField(required=False, input_formats=['%d.%m.%Y','%d.%m.%y','%m.%y'], label='Datum ukončení do (včetně)')
    ptype__exact = forms.ChoiceField(required=False, choices=[['', '']]+techtestTypeList, label='Typ')
    tout__exact = forms.ChoiceField(required=False, choices=[['', '']]+techtestFormatList, label='Formát výstupu')
    msent__exact = forms.ChoiceField(required=False, choices=[['', '']]+techtestDataList, label='Data k odeslání')
    lres__exact = forms.ChoiceField(required=False, choices=[['', '']]+techtestResultList, label='Výsledek posledního testu')
    tnum__exact = forms.IntegerField(required=False, label='Počet provedených testů', widget=forms.TextInput(attrs={'size':'5'}))

def techtest_form(request):
    t = loader.get_template('techtest.form.html')
    form = TechtestForm(request.POST)
    if request.method == "POST" and form.is_valid():
        filters = mrproper(form.cleaned_data)
        request.session['techtest'] = filters
        return HttpResponseRedirect('/techtest/result/?page=1')
    else:
        try:
            del request.session['techtest']
        except KeyError:
            pass
        c = Context({
            'form': form
        })
        return HttpResponse(t.render(c))

def techtest_result(request):
    prefix = ''
    t = loader.get_template('techtest.result.html')
    try:
        page = int(request.GET.get('page', 1))
    except ValueError:
        page = 1
    filters = request.session['techtest']
    query_set = DsdTet.objects.filter(**filters).order_by('regdate')
    paginator = Paginator(query_set, 100)
    page = int(page)
    try:
        result = paginator.page(page).object_list
    except InvalidPage:
        raise Http404
    for d in result:
        try:
            q = d.dsdqit_set.order_by('-tstdate')[0]
        except:
            q = ''
        d.qit = q
    if paginator.num_pages == 1 and paginator.count == 1:
        return HttpResponseRedirect('/techtest/%s/' % (query_set[0].dsdtet))
    pager_macro = loader.get_template('macro.pager.html').render(Context({'paginator':paginator, 'page_range': pager(paginator, page), 'page': page}))
    c = Context({
        'techtests': result,
        'pager_macro': pager_macro,
        'paginator': paginator,
    })
    return HttpResponse(t.render(c))

def techtest_detail(request, dsdtet=None, history=None):
    answer = None
    try:
        tet = DsdTet.objects.get(dsdtet=dsdtet)
    except DsdTet.DoesNotExist:
        tet = None
    t = loader.get_template('techtest.detail.html')
    c = Context({
        'tet': tet,
        'history': history,
    })
    return HttpResponse(t.render(c))

def qit_detail(request, dsdqit=None, history=None):
    try:
        qit = DsdQit.objects.get(dsdqit=dsdqit)
    except DsdQit.DoesNotExist:
        tet = None
    t = loader.get_template('qit.detail.html')
    c = Context({
        'qit': qit,
        'history': history,
    })
    return HttpResponse(t.render(c))


class BankyForm(forms.Form):

    id__exact = forms.CharField(required=False, label='Klíč', widget=forms.TextInput(attrs={'size':'35'}))
    efekt__exact = forms.ChoiceField(required=False, choices=[['', '']]+pragEfekt, label='Efekt')
    rok__exact = forms.CharField(required=False, label='Rok', widget=forms.TextInput(attrs={'size':'4'}))
    kod_dokladu__exact = forms.ChoiceField(required=False, choices=[['', '']]+pragKodDokladu, label='Kód dokladu')

    cislo_dokladu__exact = forms.CharField(required=False, label='Číslo dokladu', widget=forms.TextInput(attrs={'size':'35'}))
    cislo_radku__exact = forms.CharField(required=False, label='Číslo řádku v dokladu', widget=forms.TextInput(attrs={'size':'35'}))

    datum__gte = forms.DateField(required=False, input_formats=['%d.%m.%Y','%d.%m.%y','%m.%y'], label='Datum od')
    datum__lte = forms.DateField(required=False, input_formats=['%d.%m.%Y','%d.%m.%y','%m.%y'], label='Datum do')

    strana__exact = forms.ChoiceField(required=False, choices=[['', '']]+pragStrana, label='Strana')

    castka__exact = forms.CharField(required=False, label='Částka', widget=forms.TextInput(attrs={'size':'35'}))
    castka_zbyva__exact = forms.CharField(required=False, label='Částka zbývá doplatit', widget=forms.TextInput(attrs={'size':'35'}))

    bank_ucet__exact = forms.CharField(required=False, label='Bankovní účet protistrany', widget=forms.TextInput(attrs={'size':'35'}))
    kod_banky__exact = forms.CharField(required=False, label='Kód banky protistrany', widget=forms.TextInput(attrs={'size':'35'}))

    ks__exact = forms.CharField(required=False, label='KS', widget=forms.TextInput(attrs={'size':'35'}))
    vs__exact = forms.CharField(required=False, label='VS', widget=forms.TextInput(attrs={'size':'35'}))
    ss__exact = forms.CharField(required=False, label='SS', widget=forms.TextInput(attrs={'size':'35'}))

    vlozeno__gte = forms.DateField(required=False, input_formats=['%d.%m.%Y','%d.%m.%y','%m.%y'], label='Vloženo od')
    vlozeno__lte = forms.DateField(required=False, input_formats=['%d.%m.%Y','%d.%m.%y','%m.%y'], label='Vloženo do')


class FakturyDokladyForm(forms.Form):

    id__exact = forms.CharField(required=False, label='Klíč', widget=forms.TextInput(attrs={'size':'35'}))
    efekt__exact = forms.ChoiceField(required=False, choices=[['', '']]+pragEfekt, label='Efekt')
    rok__exact = forms.CharField(required=False, label='Rok', widget=forms.TextInput(attrs={'size':'4'}))
    kod_dokladu__exact = forms.ChoiceField(required=False, choices=[['', '']]+pragKodDokladu, label='Kód dokladu')

    cislo_dokladu__exact = forms.CharField(required=False, label='Číslo dokladu', widget=forms.TextInput(attrs={'size':'35'}))
    cislo_radku__exact = forms.CharField(required=False, label='Číslo řádku v dokladu', widget=forms.TextInput(attrs={'size':'35'}))

    datum__gte = forms.DateField(required=False, input_formats=['%d.%m.%Y','%d.%m.%y','%m.%y'], label='Datum od')
    datum__lte = forms.DateField(required=False, input_formats=['%d.%m.%Y','%d.%m.%y','%m.%y'], label='Datum do')

    strana__exact = forms.ChoiceField(required=False, choices=[['', '']]+pragStrana, label='Strana')

    castka__exact = forms.CharField(required=False, label='Částka', widget=forms.TextInput(attrs={'size':'35'}))
    castka_zbyva__exact = forms.CharField(required=False, label='Částka zbývá doplatit', widget=forms.TextInput(attrs={'size':'35'}))

    vs__exact = forms.CharField(required=False, label='VS', widget=forms.TextInput(attrs={'size':'35'}))

    vlozeno__gte = forms.DateField(required=False, input_formats=['%d.%m.%Y','%d.%m.%y','%m.%y'], label='Vloženo od')
    vlozeno__lte = forms.DateField(required=False, input_formats=['%d.%m.%Y','%d.%m.%y','%m.%y'], label='Vloženo do')

    
class VazbyForm(forms.Form):

    id__exact = forms.CharField(required=False, label='Klíč', widget=forms.TextInput(attrs={'size':'35'}))

    klic1_id__exact  = forms.CharField(  required=False, label='1. Klíč na pohyb', widget=forms.TextInput(attrs={'size':'35'}))
    klic1_typ__exact = forms.ChoiceField(required=False, label='1. Typ pohybu', choices=[['', '']]+pragVazby)
    
    klic2_id__exact  = forms.CharField(  required=False, label='2. Klíč na pohyb', widget=forms.TextInput(attrs={'size':'35'}))
    klic2_typ__exact = forms.ChoiceField(required=False, label='2. Typ pohybu', choices=[['', '']]+pragVazby)
    
    castka__exact = forms.CharField(required=False, label='Částka', widget=forms.TextInput(attrs={'size':'35'}))

    vlozeno__gte = forms.DateField(required=False, input_formats=['%d.%m.%Y','%d.%m.%y','%m.%y'], label='Vloženo od')
    vlozeno__lte = forms.DateField(required=False, input_formats=['%d.%m.%Y','%d.%m.%y','%m.%y'], label='Vloženo do')
    

    
def any_prag_form(request, type, template_prefix, classForm, title):
    "Share function for generate form page. Don't call directly."
    t = loader.get_template('%s.form.html' % template_prefix)
    t_main_menu = loader.get_template('main_menu.html').render(Context())
    form = classForm(request.POST)
    if request.method == "POST" and form.is_valid():
        filters = mrproper(form.cleaned_data) # form.clean_data
        request.session[type] = filters
        return HttpResponseRedirect('/%s/result/?page=1'%type)
    else:
        try:
            del request.session[type]
        except KeyError:
            pass
        c = Context({
            'main_menu': t_main_menu, 
            'title': title, 
            'form': form
        })
        return HttpResponse(t.render(c))


    
def any_prag_result(request, type, template_prefix, classResult, title):
    "Share function for generate result page. Don't call directly."
    try:
        page = int(request.GET.get('page', 1))
    except ValueError:
        page = 1
    t = loader.get_template('%s.result.html' % template_prefix)
    t_main_menu = loader.get_template('main_menu.html').render(Context())
    filters = request.session[type]
    paginator = Paginator(classResult.objects.filter(**filters).order_by('vlozeno'), 100)
    page = int(page)
    try:
        result = paginator.page(page).object_list
    except InvalidPage:
        raise Http404
        
    pager_macro = loader.get_template('macro.pager.html').render(Context({'paginator':paginator, 'page_range': pager(paginator, page), 'page': page}))
    c = Context({
        'type': type,
        'main_menu': t_main_menu, 
        'title': title, 
        'records': result,
        'pager_macro': pager_macro,
        'paginator': paginator,
    })
    return HttpResponse(t.render(c))


def banky_form(request):
    return any_prag_form(request, 'banky', 'banky', BankyForm, 'banky (typ B)')

def platby_form(request):
    return any_prag_form(request, 'platby', 'banky', BankyForm, 'platby (typ V)')

def faktury_form(request):
    return any_prag_form(request, 'faktury', 'banky', FakturyDokladyForm, 'faktury (typ O)')

def vnitrni_doklady_form(request):
    return any_prag_form(request, 'vnitrni_doklady', 'banky', FakturyDokladyForm, 'vnitřní doklady (typ I)')
    
def vazby_form(request):
    return any_prag_form(request, 'vazby', 'banky', VazbyForm, 'vazby')


def banky_result(request):
    return any_prag_result(request, 'banky', 'banky', PragBanky, 'banky (typ B)')

def platby_result(request):
    return any_prag_result(request, 'platby', 'banky', PragPlatby, 'platby (typ V)')

def faktury_result(request):
    return any_prag_result(request, 'faktury', 'faktury', PragFaktury, 'faktury (typ O)')

def vnitrni_doklady_result(request):
    return any_prag_result(request, 'vnitrni_doklady', 'faktury', PragVnitrniDoklady, 'vnitřní doklady (typ I)')

def vazby_result(request):
    return any_prag_result(request, 'vazby', 'vazby', PragVazby, 'vazby')

    
def vazby_detail_result(request, typ, id):

    # (template_key, class, title)
    obj = {
        'B': ('banky',   PragBanky, 'banky (typ B)'), 
        'V': ('banky',   PragPlatby, 'platby (typ V)'), 
        'I': ('faktury', PragFaktury, 'faktury (typ O)'), 
        'O': ('faktury', PragVnitrniDoklady, 'vnitřní doklady (typ I)'), 
        }
    t = loader.get_template('vazby_detail_%s.result.html' % obj[typ][0])
    filters= {'id__exact': id}
    paginator = Paginator(obj[typ][1].objects.filter(**filters), 1)
    try:
        result = paginator.page(1).object_list
    except InvalidPage:
        raise Http404

    return HttpResponse(t.render(Context({'item': len(result) and result[0] or {}, 'title':obj[typ][2]})))


