from distutils.version import StrictVersion
from distutils.dir_util import mkpath
from distutils import util
from distutils import log
from distutils.file_util import copy_file

from freddist.core import setup
from freddist.command.install import install
from freddist.command.install_lib import install_lib
from freddist.command.install_data import install_data
from freddist.command.install_scripts import install_scripts
from freddist.file_util import *

import os
import sys
import re
import types

def njoin(*args):
    return os.path.normpath('/'.join(args))


PROJECT_NAME = 'fred-rexeso'
PACKAGE_NAME = 'rexeso'
PACKAGE_VERSION = '1.0.0'

SHARE_PACKAGE = njoin('share', PROJECT_NAME)

CONFIG_DIR = 'fred/'
INIT_DIR = 'init.d/'
BIN_DIR = 'sbin/'

EXCLUDE_FILES = ['.svn']

class RexesoInstall(install):
    user_options = []
    user_options.extend(install.user_options)

    # boolean_options = install.boolean_options
    # boolean_options.append('nodepcheck')
    
    def initialize_options(self):
        install.initialize_options(self)
        
    def finalize_options(self):
        install.finalize_options(self)

    def check_simplejson(self):
        try:
            import simplejson
        except ImportError, msg:
            sys.stderr.write('ImportError: %s\n fred-rexeso needs simplejson module.\n'%msg)
            sys.exit(1)

    def check_django(self):
        try:
            import django
        except ImportError, msg:
            sys.stderr.write('ImportError: %s\n fred-rexeso needs django module.\n'%msg)
            sys.exit(1)
    
    def check_dependencies(self):
        'Check all dependencies'
        self.check_simplejson()
        self.check_django()

    def run(self):
        #if not self.nodepcheck:
        if not self.no_check_deps:
            print 'Checking dependencies.'
            self.check_dependencies()

        install.run(self)
        
        #self.update_config_and_run_file()
        #mkpath(njoin(self.root, self.localstatedir, SESSION_DIR))

class RexesoInstallLib(install_lib):
    def update_config_py(self):
        values = [(r'(sys\.path\.insert\(0, )\'[\/\w\ \.]*\'\)',
            r"\1'%s')" % os.path.join(self.getDir('sysconfdir'), CONFIG_DIR))]
        print values
        print self.build_dir
        self.replace_pattern(os.path.join(self.build_dir, 'rexeso_cfg.py'),
                None, values)
        print "rexeso_cfg.py file has been updated."

    def run(self):
        self.update_config_py()
        install_lib.run(self)
        
class RexesoInstallData(install_data):
    user_options = install_data.user_options

    def initialize_options(self):
        install_data.initialize_options(self)

    def finalize_options(self):
        self.set_undefined_options('install',
        )
        
        install_data.finalize_options(self)

#    def update_rexeso_cfg(self):
#        values = []
#        values.append(('DU_PORT', self.port))
#
#        self.replace_pattern(
#                os.path.join(self.srcdir, 'webadmin_cfg.py.install'),
#                os.path.join('build', 'webadmin_cfg.py'), values)
#        print "webadmin_cfg.py files has been updated"

#    def update_fred_webadmin(self):
#        values = []
#        values.append(('DU_PYTHON_PATHS', "'%s', '%s'" % (os.path.join(
#                self.getDir('sysconfdir'), CONFIG_DIR),
#                self.getDir('purelibdir'))))
#
#        self.replace_pattern(
#                os.path.join(self.srcdir, 'fred-webadmin.install'),
#                os.path.join('build', 'fred-webadmin'), values)
#        print "fred-webadmin script has been updated"

#    def update_webadmin_server(self):
#        values = []
#        values.append(('DU_PREFIX', self.getDir('prefix')))
#        self.replace_pattern(
#                os.path.join(self.srcdir, 'fred-webadmin-server.install'),
#                os.path.join('build', 'fred-webadmin-server'),
#                values)
#        print "fred-webadmin-server script has been udpated"

#    def run(self):
#        self.update_webadmin_cfg()
#        self.update_fred_webadmin()
#        self.update_webadmin_server()
#        install_data.run(self)

def main(directory):
    if len(directory) == 0:
        cut = 0
    else:
        cut = directory.count(os.path.sep) + 1
    try:
        setup(name = PROJECT_NAME,
              description = 'Admin Interface for DSD Database',
              author = 'David Pospisilik, Tomas Divis, CZ.NIC',
              author_email = 'tomas.divis@nic.cz',
              url = 'http://www.nic.cz',
              version = PACKAGE_VERSION,
              #packages = all_subpackages_in('./'),
              #package_dir = {PACKAGE_NAME: PACKAGE_NAME},
              data_files = [
                  ('SYSCONFDIR/fred', ['rexeso_cfg.py']),
                  ]
              # + all_files_in(
                  # os.path.join('DATAROOTDIR', PROJECT_NAME, 'www'),
                  # os.path.join(directory, 'www'),
                  # cutSlashes_dst=cut
                  # )
              # + all_files_in(
                  # os.path.join('DATAROOTDIR', PROJECT_NAME, 'locale'),
                  # os.path.join(directory, 'locale'),
                  # cutSlashes_dst=cut
                  # ),
                  + all_files_in_4(
                      os.path.join(SHARE_PACKAGE, PROJECT_NAME, 'media'),
                      os.path.join(directory, 'media'))
                  + all_files_in_4(
                      os.path.join(SHARE_PACKAGE, PROJECT_NAME, 'browser'),
                      os.path.join(directory, 'browser'))
                  + [(os.path.join(SHARE_PACKAGE, PROJECT_NAME), [
                        os.path.join(directory, 'manage.py'),
                        os.path.join(directory, '__init__.py'),
                        os.path.join(directory, 'urls.py'),
                        os.path.join(directory, 'README.utf8'),
                        os.path.join(directory, 'settings.py')
                      ]
                    )],
                      
              cmdclass = {
                          'install': RexesoInstall,
                          'install_data': RexesoInstallData,
                          'install_lib': RexesoInstallLib,
                         },
        )
        return True
    except Exception, e:
        log.error("Error: %s", e)
        return False
    
if __name__ == '__main__':
    dir = ''
    if 'bdist' in sys.argv:
        dir = ''
    else:
        dir = os.path.dirname(sys.argv[0])
    if main(dir):
        print "All done!"
